@@ -6,9 +6,9 @@
 #include <unistd.h>
 #include <sys/wait.h>
 
-#include <fox-1.4/fx.h>
-#include <fox-1.4/fxkeys.h>
-#include <fox-1.4/FXPNGIcon.h>
+#include <fox-1.6/fx.h>
+#include <fox-1.6/fxkeys.h>
+#include <fox-1.6/FXPNGIcon.h>
 
 #include "xfedefs.h"
 #include "icons.h"
@@ -27,6 +27,7 @@
 extern FXString clipboard;
 extern FXuint clptype;
 extern FXMainWindow *mainWindow;
+extern FXbool allowPopupScroll;
 #if defined(linux)
 extern FXStringDict* fsdevices;
 extern FXStringDict* mtdevices;
@@ -46,7 +47,8 @@ FXDEFMAP(DirPanel) DirPanelMap[]={
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_MOVE,DirPanel::onCmdDirMan),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_RENAME,DirPanel::onCmdDirMan),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_SYMLINK,DirPanel::onCmdDirMan),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_DELETE,DirPanel::onCmdDirDel),
+                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_DELETE,DirPanel::onCmdDirDelete),
+                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_TRASH,DirPanel::onCmdDirTrash),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_NEW_DIR,DirPanel::onCmdNewDir),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_XTERM,DirPanel::onCmdXTerm),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_COPY_CLP,DirPanel::onCmdClp),
@@ -61,7 +63,7 @@ FXDEFMAP(DirPanel) DirPanelMap[]={
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_UMOUNT,DirPanel::onCmdMount),
                                	   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_MOUNT,DirPanel::onUpdMount),
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_UMOUNT,DirPanel::onUpdUnmount),
-#endif								   
+#endif
                                	   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_PASTE_CLP,DirPanel::onUpdPaste),
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TOGGLE_HIDDEN,DirPanel::onUpdToggleHidden),
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TOGGLE_TREE,DirPanel::onUpdToggleTree),
@@ -69,7 +71,8 @@ FXDEFMAP(DirPanel) DirPanelMap[]={
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_ARCHIVE,DirPanel::onUpdMenu),
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_MOVE,DirPanel::onUpdMenu),
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_RENAME,DirPanel::onUpdMenu),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_DELETE,DirPanel::onUpdMenu),
+                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_TRASH,DirPanel::onUpdDirTrash),
+                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_DELETE,DirPanel::onUpdDirDelete),
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_NEW_DIR,DirPanel::onUpdMenu),
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TITLE,DirPanel::onUpdTitle),
                           		};
@@ -81,29 +84,6 @@ FXIMPLEMENT(DirPanel,FXVerticalFrame,DirPanelMap,ARRAYNUMBER(DirPanelMap))
 DirPanel::DirPanel(FXComposite *p, FXColor listbackcolor, FXColor listforecolor, FXuint opts, FXint x, FXint y, FXint w, FXint h):
         FXVerticalFrame(p,opts,x,y,w,h,0,0,0,0)
 {
-	// Create some icons
-	attricon=new FXPNGIcon(getApp(),attrib);
-    archicon=new FXPNGIcon(getApp(),arch);
-    sorticon=new FXPNGIcon(getApp(),sort);
-    newfoldericon=new FXPNGIcon(getApp(),newfolder);
-	delicon=new FXPNGIcon(getApp(),filedelete);	
-	copyicon=new FXPNGIcon(getApp(),copy_clp);	
-	cuticon=new FXPNGIcon(getApp(),cut_clp);	
-	pasteicon=new FXPNGIcon(getApp(),paste_clp);	
-	mapicon=new FXPNGIcon(getApp(),maphost);	
-	unmapicon=new FXPNGIcon(getApp(),unmaphost);	
-	xtermicon=new FXPNGIcon(getApp(),shell);
-	symlinkicon=new FXPNGIcon(getApp(),minilink);
-	renameicon=new FXPNGIcon(getApp(),renameit);
-	moveicon=new FXPNGIcon(getApp(),moveit);
-	exptreeicon=new FXPNGIcon(getApp(),exptree);
-	expfoldericon=new FXPNGIcon(getApp(),expfolder);
-	colltreeicon=new FXPNGIcon(getApp(),colltree);
-	collfoldericon=new FXPNGIcon(getApp(),collfolder);
-
-	FXIcon *showhiddenicon=new FXPNGIcon(getApp(),showhidden);
-	FXIcon *hidehiddenicon=new FXPNGIcon(getApp(),hidehidden);
-
 	// Construct directory panel
     FXVerticalFrame* cont=new FXVerticalFrame(this,LAYOUT_FILL_Y|LAYOUT_FILL_X|FRAME_SUNKEN,0,0,0,0, 0,0,0,0, 1,1);
 	FXPacker* packer=new FXHorizontalFrame(cont,JUSTIFY_LEFT|LAYOUT_FILL_X|FRAME_RAISED,0,0,0,0, 0,0,0,0);
@@ -119,6 +99,12 @@ DirPanel::DirPanel(FXComposite *p, FXColor listbackcolor, FXColor listforecolor,
     status=new FXLabel(statusbar,_("Status"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X|FRAME_SUNKEN);
     status->setTarget(this);
     status->setSelector(FXSEL(SEL_UPDATE,DirPanel::ID_TITLE));
+
+	// Home and trahscan locations
+	homelocation=getenv("HOME");
+    if(homelocation=="")
+        homelocation=ROOTDIR;
+	trashlocation=homelocation+PATHSEPSTRING+TRASHPATH;
 }
 
 
@@ -126,24 +112,6 @@ DirPanel::DirPanel(FXComposite *p, FXColor listbackcolor, FXColor listforecolor,
 DirPanel::~DirPanel()
 {
     getApp()->removeTimeout(this,ID_DIRSIZE_REFRESH);
-	delete attricon;
-	delete archicon;
-	delete sorticon;
-	delete newfoldericon;
-	delete delicon;
-	delete copyicon;
-	delete cuticon;
-	delete pasteicon;
-	delete mapicon;
-	delete unmapicon;
-	delete xtermicon;
-	delete symlinkicon;
-	delete renameicon;
-	delete moveicon;
-	delete exptreeicon;
-	delete expfoldericon;
-	delete colltreeicon;
-	delete collfoldericon;
 	delete list;
 	delete statusbar;
 	delete status;
@@ -173,12 +141,13 @@ long DirPanel::onCmdDirectory(FXObject*,FXSelector,void* ptr)
         FXString directory=list->getItemPathname(item);
         if(!::isReadExecutable(directory))
         {
-            MessageBox::error(this,MBOX_OK,_("Error"),_(" Permission to: %s denied."), directory.text());
+            MessageBox::error(this,BOX_OK_SU,_("Error"),_(" Permission to: %s denied."), directory.text());
             return 0;
         }
 		FilePanel* currentpanel=((XFileExplorer*) mainWindow)->lpanel->current;
 		FXComboBox* address=((XFileExplorer*) mainWindow)->address;
         currentpanel->list->setDirectory(directory);
+        currentpanel->updatePathLinker();
         
 		// Remember latest directory in the location address
        	FXString item;
@@ -258,6 +227,7 @@ long DirPanel::onPopupMenu(FXObject* o,FXSelector s,void* p)
 	FXString dir=list->getItemPathname((TreeItem*)item);
 	list->setDirectory(dir,TRUE);
 	((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(dir);
+	((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
 
     // Popup menu pane
     FXMenuPane menu(this);
@@ -266,43 +236,43 @@ long DirPanel::onPopupMenu(FXObject* o,FXSelector s,void* p)
 #if defined(linux)
 	if (::isLink(dir))
 		dir=readlink(dir);
-    if(fsdevices->find(dir.text()))
+    if(fsdevices->find(dir.text()) || mtdevices->find(dir.text()))
 	{
-		new FXMenuCommand(&menu,_("&Mount"),mapicon,this,ID_MOUNT);
-		new FXMenuCommand(&menu,_("Unmount"),unmapicon,this,ID_UMOUNT);
+		new FXMenuCommand(&menu,_("M&ount"),maphosticon,this,ID_MOUNT);
+		new FXMenuCommand(&menu,_("Unmoun&t"),unmaphosticon,this,ID_UMOUNT);
     	new FXMenuSeparator(&menu);
 	}
 #endif
-    new FXMenuCommand(&menu,_("&Terminal"),xtermicon,this,DirPanel::ID_XTERM);
-	new FXMenuCommand(&menu,_("New f&older..."),newfoldericon,this,DirPanel::ID_NEW_DIR);
-	new FXMenuCommand(&menu,_("&Add to archive..."),archicon,this,DirPanel::ID_ARCHIVE);
+	new FXMenuCommand(&menu,_("New &folder..."),newfoldericon,this,DirPanel::ID_NEW_DIR);
+	new FXMenuCommand(&menu,_("&Add to archive..."),archaddicon,this,DirPanel::ID_ARCHIVE);
     new FXMenuSeparator(&menu);
-	new FXMenuCommand(&menu,_("&Copy"),copyicon,this,DirPanel::ID_COPY_CLP);
-	new FXMenuCommand(&menu,_("C&ut"),cuticon,this,DirPanel::ID_CUT_CLP);
-	new FXMenuCommand(&menu,_("&Paste"),pasteicon,this,DirPanel::ID_PASTE_CLP);
+	new FXMenuCommand(&menu,_("&Copy"),copy_clpicon,this,DirPanel::ID_COPY_CLP);
+	new FXMenuCommand(&menu,_("C&ut"),cut_clpicon,this,DirPanel::ID_CUT_CLP);
+	new FXMenuCommand(&menu,_("&Paste"),paste_clpicon,this,DirPanel::ID_PASTE_CLP);
     new FXMenuSeparator(&menu);
-	new FXMenuCommand(&menu,_("Re&name..."),renameicon,this,DirPanel::ID_DIR_RENAME);
-	new FXMenuCommand(&menu,_("Copy &to..."),copyicon,this,DirPanel::ID_DIR_COPYTO);
-	new FXMenuCommand(&menu,_("&Move..."),moveicon,this,DirPanel::ID_DIR_MOVE);
-	new FXMenuCommand(&menu,_("Symlin&k..."),symlinkicon,this,DirPanel::ID_DIR_SYMLINK);
-	new FXMenuCommand(&menu,_("&Delete"),delicon,this,DirPanel::ID_DIR_DELETE);
+	new FXMenuCommand(&menu,_("Re&name..."),renameiticon,this,DirPanel::ID_DIR_RENAME);
+	new FXMenuCommand(&menu,_("Cop&y to..."),copy_clpicon,this,DirPanel::ID_DIR_COPYTO);
+	new FXMenuCommand(&menu,_("&Move to..."),moveiticon,this,DirPanel::ID_DIR_MOVE);
+	new FXMenuCommand(&menu,_("Symlin&k..."),minilinkicon,this,DirPanel::ID_DIR_SYMLINK);
+	new FXMenuCommand(&menu,_("Mo&ve to trash"),filedeleteicon,this,DirPanel::ID_DIR_TRASH);
+	new FXMenuCommand(&menu,_("&Delete"),filedelete_permicon,this,DirPanel::ID_DIR_DELETE);
     new FXMenuSeparator(&menu);
 	new FXMenuCheck(&menu,_("&Hidden folders"),this,DirPanel::ID_TOGGLE_HIDDEN);
 	new FXMenuCommand(&menu,_("&Reverse order"),sorticon,this,DirPanel::ID_SORT_REVERSE);
 	new FXMenuCommand(&menu,_("E&xpand tree"),exptreeicon,this,DirPanel::ID_EXPANDTREE);
 	new FXMenuCommand(&menu,_("Collap&se tree"),colltreeicon,this,DirPanel::ID_COLLAPSETREE);
     new FXMenuSeparator(&menu);
-	new FXMenuCommand(&menu,_("Proper&ties"),attricon,this,DirPanel::ID_PROPERTIES);
+	new FXMenuCommand(&menu,_("Prop&erties"),attribicon,this,DirPanel::ID_PROPERTIES);
 	
     menu.create();
-    menu.popup(NULL,x,y);
+    allowPopupScroll=TRUE;  // Allow keyboard scrolling
+	menu.popup(NULL,x,y);
 	getApp()->runModalWhileShown(&menu);
+    allowPopupScroll=FALSE;
     return 1;
 }
 
 
-
-
 // Helper function used to explore the directory tree and expand or collapse it
 long DirPanel::exploreUp(DirItem *item, const DirItem *rootitem, const FXint task)
 {
@@ -384,7 +354,7 @@ long DirPanel::onCmdProperties(FXObject* sender,FXSelector,void* ptr)
 	DirItem* item=(DirItem*)list->getCurrentItem();
 	FXString pathname=list->getItemPathname((TreeItem*)item);
 	
-	PropertiesBox* attrdlg=new PropertiesBox(this,FXFile::name(pathname),FXFile::directory(pathname));	
+	PropertiesBox* attrdlg=new PropertiesBox(this,FXPath::name(pathname),FXPath::directory(pathname));	
    	if(attrdlg->execute(PLACEMENT_SCREEN))
         list->setDirectory(pathname,TRUE);
     delete attrdlg;
@@ -399,8 +369,8 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector sel,void* ptr)
     DirItem* item=(DirItem*)list->getCurrentItem();
 	FXString name=list->getItemText(item);
 	FXString pathname=list->getItemPathname((TreeItem*)item);	
-	FXString parentdir=FXFile::directory(pathname);
-	FXString cmd;
+	FXString parentdir=FXPath::directory(pathname);
+	FXString cmd, ext1, ext2;
 	FXString archive=name;
 	
     static char history[ADD_TO_ARCH_HIST_SIZE][100];
@@ -408,30 +378,50 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector sel,void* ptr)
     int i;
 	File *f;	
     HistInputDialog* dialog;
-    
-	dialog=new HistInputDialog(this,archive,
-	       _("Create new archive: (e.g. archive.tar.gz)\n=>Supported formats : tar, tgz, tbz2, taz, zip, rar, lzh"),
-	       _("Add To Archive"));
-    for(int i=0;i<n;i++)
+    	
+	dialog=new HistInputDialog(this,archive,_("Create new archive: (e.g. archive.tar.gz)\n=>Supported formats : tar, tgz, tbz2, taz, zip, rar, lzh"),_("Add To Archive"));
+   	dialog->appendItem((char *)archive.text());
+
+	for(int i=0;i<n;i++)
         dialog->appendItem(history[i]);
     dialog->CursorEnd();
     if(dialog->execute())
     {
         archive="\""+parentdir+PATHSEPSTRING+dialog->getText()+"\"";
 
-        // Handle zip and bz2 archives
-        FXString ext=dialog->getText().rafter('.',1);
-		ext.lower();
-		if (ext=="zip")
-            cmd="zip -r ";
-        else if (ext=="bz2" || ext=="tbz2")
+        // Get extensions of the archive name
+        ext1=dialog->getText().rafter('.',1);
+		ext1.lower();
+        ext2=dialog->getText().rafter('.',2);
+		ext2.lower();
+		
+		// Handle different archive formats
+		if (ext2=="tar.gz")
+            cmd="tar -zcvf ";
+		else if (ext2=="tar.bz2")
             cmd="tar -jcvf ";
-		else if (ext=="rar")
-			cmd="rar a ";
-		else if (ext=="lzh")
-			cmd="lha a ";
-		else if (ext=="z")
-			cmd="tar -Zcvf ";
+		else if (ext2=="tar.z")
+           	cmd="tar -Zcvf ";
+		else if (ext1=="tar")
+           	cmd="tar -cvf ";
+		else if (ext1=="gz")
+			cmd="gzip -v ";				
+		else if (ext1=="tgz")
+            cmd="tar -zcvf ";
+		else if (ext1=="bz2")
+			cmd="bzip2 -v ";				
+		else if (ext1=="tbz2")
+            cmd="tar -jcvf ";
+		else if (ext1=="z")
+            cmd="compress -v ";
+		else if (ext1=="zip")
+            cmd="zip -r ";
+		else if (ext1=="rar")
+            cmd="rar a ";
+		else if (ext1=="lzh")
+            cmd="lha a ";
+		else
+			cmd="tar -zcvf ";
 
 		// Archive command name
 		cmd=cmd+archive+" "+"\""+name+"\"";
@@ -448,7 +438,7 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector sel,void* ptr)
 		if (f->isCancelled)
 		{
 			f->hide();
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Archive creation cancelled!"));
+			MessageBox::error(this,BOX_OK,_("Error"),_("Archive creation cancelled!"));
 		}					
 		delete f; 
 
@@ -473,6 +463,7 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector sel,void* ptr)
 		// Display parent directory in DirList and FileList
 		list->setDirectory(parentdir,TRUE);
 		((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
+		((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
     }
     delete dialog;
     return 1;
@@ -488,7 +479,7 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void*)
 	// Parameters passed to XFileExplorer::onCmdFileMan
 	// -1 is used to tell that we are calling from DirPanel
 	FXString source=list->getItemPathname((TreeItem*)item);	
-    FXString target=FXFile::directory(source);
+    FXString target=FXPath::directory(source);
 	FXString param=target+"\n"+"-1"+"\n"+source;
 
     switch(FXSELID(sel))
@@ -525,32 +516,31 @@ long DirPanel::onCmdSortReverse(FXObject* sender,FXSelector sel,void*)
 
 
 // Delete directory
-long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
+long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
 {
 	// Current item
     DirItem* item=(DirItem*)list->getCurrentItem();
 	FXString pathname=list->getItemPathname((TreeItem*)item);	
-	FXString parentdir=FXFile::directory(pathname);	
+	FXString parentdir=FXPath::directory(pathname);	
 
     // If we don't have permission to write to the parent directory
     if(!::isWritable(parentdir))
     {
-        MessageBox::error(this,MBOX_OK,_("Error"),_("Can't write to %s: Permission denied"), parentdir.text());
+        MessageBox::error(this,BOX_OK_SU,_("Error"),_("Can't write to %s: Permission denied"), parentdir.text());
         return 0;
     }
 
     FXbool confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
 	if(confirm_del)
     {
-        FXPNGIcon icon(getApp(),delete_big);
-		FXString message=_("Delete folder ") + pathname + " ?";
-		MessageBox box(this,_("Confirm Delete"),message,&icon,MBOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
-        if(box.execute(PLACEMENT_CURSOR) != MBOX_CLICKED_OK)
+		FXString message=_("Definitively delete folder ") + pathname + " ?";
+		MessageBox box(this,_("Confirm Delete"),message,delete_big_permicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
+        if(box.execute(PLACEMENT_CURSOR) != BOX_CLICKED_OK)
             return 0;
     }
 
 	// File object
-   	File* f=new File(this,_("File Delete"),DELETE);
+   	File* f=new File(this,_("File delete"),DELETE);
    	f->create();
 
     // If we don't have permission to write to the directory
@@ -559,7 +549,7 @@ long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
 		// Get process uid and directory uid
 		FXuint uid=getuid();
 		struct stat buf;
-		lstatout(pathname.text(),&buf);
+		lstatrep(pathname.text(),&buf);
 		FXuint diruid=buf.st_uid;
 
 		// If we are owner of the directory
@@ -568,21 +558,21 @@ long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
 			// Dialog to confirm directory deletion
 			f->allowPdialog=FALSE;
 			f->hide();
-			FXPNGIcon icon(getApp(),errorIcon);
-			FXString str=_("Folder ") + pathname + _(" is write-protected, delete it anyway?");
-        	MessageBox box(this,_("Confirm Delete"),str,&icon,MBOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
+			FXString str=_("Folder ") + pathname + _(" is write-protected, definitively delete it anyway?");
+        	MessageBox box(this,_("Confirm Delete"),str,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
 			FXuint answer=box.execute(PLACEMENT_SCREEN);
-			if(answer == MBOX_CLICKED_OK)
+			if(answer == BOX_CLICKED_OK)
 			{
 				f->remove(pathname); 	
 
 				// If action is cancelled in progress dialog
 				if (f->isCancelled)
-					MessageBox::error(this,MBOX_OK,_("Error"),_("Delete folder operation cancelled!"));
+					MessageBox::error(this,BOX_OK,_("Error"),_("Delete folder operation cancelled!"));
 				
 				// Return to parent directory in DirList and FileList
 				list->setDirectory(parentdir,TRUE);
 				((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
+				((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
 			}
 		}
 					
@@ -591,7 +581,7 @@ long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
 		{
 			f->allowPdialog=FALSE;
 			f->hide();
-        	MessageBox::error(this,MBOX_OK,_("Error"),_("Can't delete folder %s: Permission denied"), pathname.text());
+        	MessageBox::error(this,BOX_OK_SU,_("Error"),_("Can't delete folder %s: Permission denied"), pathname.text());
     	}
 	}
 
@@ -604,11 +594,159 @@ long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
 		if (f->isCancelled)
 		{
 			f->hide();
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Delete file operation cancelled!"));
+			MessageBox::error(this,BOX_OK,_("Error"),_("Delete folder operation cancelled!"));
 		}
 		// Return to parent directory in DirList and FileList
 		list->setDirectory(parentdir,TRUE);
 		((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
+		((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
+	}
+
+	delete f;
+
+	// Force DirPanel and FilePanel refresh
+ 	//mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_REFRESH),NULL);
+	list->onRefresh(0,0,0);
+    return 1;
+}
+
+
+// Move directory to trash can
+long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
+{
+	FXbool ret;
+	
+	// Current item
+    DirItem* item=(DirItem*)list->getCurrentItem();
+	FXString pathname=list->getItemPathname((TreeItem*)item);	
+	FXString parentdir=FXPath::directory(pathname);	
+
+    // If we don't have permission to write to the parent directory
+    if(!::isWritable(parentdir))
+    {
+        MessageBox::error(this,BOX_OK_SU,_("Error"),_("Can't write to %s: Permission denied"), parentdir.text());
+        return 0;
+    }
+
+    FXbool confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
+	if(confirm_del)
+    {
+		FXString message=_("Move folder ") + pathname + " to trash ?";
+		MessageBox box(this,_("Confirm Trash"),message,delete_bigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
+        if(box.execute(PLACEMENT_CURSOR) != BOX_CLICKED_OK)
+            return 0;
+    }
+
+	// File object
+   	File* f=new File(this,_("Move to trash"),DELETE);
+   	f->create();
+
+    // If we don't have permission to write to the directory
+ 	if (!::isLWritable(pathname))
+    {
+		// Get process uid and directory uid
+		FXuint uid=getuid();
+		struct stat buf;
+		lstatrep(pathname.text(),&buf);
+		FXuint diruid=buf.st_uid;
+
+		// If we are owner of the directory
+		if (diruid==uid)
+		{
+			// Dialog to confirm directory deletion
+			f->allowPdialog=FALSE;
+			f->hide();
+			FXString str=_("Folder ") + pathname + _(" is write-protected, move it to trash can anyway?");
+        	MessageBox box(this,_("Confirm Trash"),str,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
+			FXuint answer=box.execute(PLACEMENT_SCREEN);
+			if(answer == BOX_CLICKED_OK)
+			{
+				
+				// Folder is in the trash can
+				if (pathname.find(trashlocation.text())==0)
+				{
+					FXString message=_("Folder is already in the trash can! Definitively delete folder ") + pathname + " ?";
+					MessageBox box(this,_("Delete from trash can"),message,delete_big_permicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
+					if(box.execute(PLACEMENT_CURSOR) == BOX_CLICKED_OK)
+						f->remove(pathname);
+					f->allowPdialog=TRUE;
+				}
+				else
+				{
+					// Create trash can if it doesn't exist
+					if (!exists(trashlocation))
+						::mkdir(trashlocation.text(),0755);
+					
+					// Move folder to trash can
+					ret=f->move(pathname,trashlocation+PATHSEPSTRING+stampname(pathname));
+					
+					// An error has occurred
+					if (ret==0 && !f->isCancelled)
+					{
+						f->hide();
+						MessageBox::error(this,BOX_OK,_("Error"),_("An error has occurred during the move to trash operation!"));
+					}
+				}
+
+				// If action is cancelled in progress dialog
+				if (f->isCancelled)
+					MessageBox::error(this,BOX_OK,_("Error"),_("Move to trash folder operation cancelled!"));
+				
+				// Return to parent directory in DirList and FileList
+				list->setDirectory(parentdir,TRUE);
+				((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
+				((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
+			}
+		}
+					
+		// If we are not owner of the directory
+		else
+		{
+			f->allowPdialog=FALSE;
+			f->hide();
+        	MessageBox::error(this,BOX_OK_SU,_("Error"),_("Can't move folder %s to trash can: Permission denied"), pathname.text());
+    	}
+	}
+
+	// If we have permission to write
+	else
+	{
+		// Folder is in the trash can
+		if (pathname.find(trashlocation.text())==0)
+		{
+			f->allowPdialog=FALSE;
+			f->hide();
+			FXString message=_("Folder is already in the trash can! Definitively delete folder ") + pathname + " ?";
+       		MessageBox box(this,_("Delete from trash can"),message,delete_big_permicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
+			if(box.execute(PLACEMENT_CURSOR) == BOX_CLICKED_OK)
+				f->remove(pathname);
+			f->allowPdialog=TRUE;
+		}
+		else
+		{
+			// Create trash can if it doesn't exist
+			if (!exists(trashlocation))
+				::mkdir(trashlocation.text(),0755);
+			ret=f->move(pathname,trashlocation+PATHSEPSTRING+stampname(pathname));
+
+			// An error has occurred
+			if (ret==0 && !f->isCancelled)
+			{
+				f->hide();
+				MessageBox::error(this,BOX_OK,_("Error"),_("An error has occurred during the move to trash operation!"));
+			}
+		}
+
+		// If action is cancelled in progress dialog
+		if (f->isCancelled)
+		{
+			f->hide();
+			MessageBox::error(this,BOX_OK,_("Error"),_("Move to trash folder operation cancelled!"));
+		}
+		// Return to parent directory in DirList and FileList
+		list->setDirectory(parentdir,TRUE);
+		((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
+		((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
 	}
 
 	delete f;
@@ -646,7 +784,7 @@ long DirPanel::onCmdNewDir(FXObject*,FXSelector,void*)
 			FXint ret=::mkdir(dirname.text(),511 & ~mask);
 			if (ret==-1)
 			{
-         		MessageBox::error(this,MBOX_OK,_("Error"),"%s",strerror(errno));
+         		MessageBox::error(this,BOX_OK,_("Error"),"%s",strerror(errno));
     			return 0;
 			}
 		}							
@@ -753,7 +891,7 @@ long DirPanel::onCmdMount(FXObject*,FXSelector sel,void*)
 		msg=_("Unmount");
         cmd="umount ";
     }
-    cmd+=dir;
+    cmd+="'"+dir+"'";
     cmd+=" 2>&1";
     chdir(ROOTDIR);
 
@@ -772,9 +910,10 @@ long DirPanel::onCmdMount(FXObject*,FXSelector sel,void*)
 	// If action is cancelled in progress dialog
 	if (f->isCancelled)
 	{
+		getApp()->endWaitCursor();
 		f->hide();
 		text=msg + _(" operation cancelled!");
-		MessageBox::error(this,MBOX_OK,_("Error"),text.text());
+		MessageBox::error(this,BOX_OK,_("Error"),text.text());
 		delete f;
 		return 0;
 	}					
@@ -811,7 +950,7 @@ long DirPanel::onUpdUnmount(FXObject* o,FXSelector sel,void*)
     DirItem* item=(DirItem*)list->getCurrentItem();
 	FXString dir=list->getItemPathname((TreeItem*)item);
 
-    if(fsdevices->find(dir.text()) && mtdevices->find(dir.text()))
+    if(fsdevices->find(dir.text()) || mtdevices->find(dir.text()))
         o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
     else
         o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
@@ -853,6 +992,51 @@ long DirPanel::onUpdMenu(FXObject* o,FXSelector,void*)
     return 1;
 }
 
+// Update menu items and toolbar buttons that are related to file operations
+long DirPanel::onUpdDirDelete(FXObject* o,FXSelector,void*)
+{
+	// Name of the current selected item
+	TreeItem* item=(TreeItem*)list->getCurrentItem();
+	
+	// There is no selected item
+	if (item==NULL)
+		return 0;
+	
+	// Path name of the selected item
+	FXString dir=list->getItemPathname(item);	
+
+ 	FXbool use_trash_can=getApp()->reg().readUnsignedEntry("OPTIONS","use_trash_can",TRUE);
+	FXbool use_trash_bypass=getApp()->reg().readUnsignedEntry("OPTIONS","use_trash_bypass",FALSE);
+	if (!use_trash_can | use_trash_bypass)
+		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
+	else
+		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
+
+	return 1;
+}
+
+
+// Update menu items and toolbar buttons that are related to file operations
+long DirPanel::onUpdDirTrash(FXObject* o,FXSelector,void*)
+{
+	// Name of the current selected item
+	TreeItem* item=(TreeItem*)list->getCurrentItem();
+	
+	// There is no selected item
+	if (item==NULL)
+		return 0;
+	
+	// Path name of the selected item
+	FXString dir=list->getItemPathname(item);	
+
+	FXbool use_trash_can=getApp()->reg().readUnsignedEntry("OPTIONS","use_trash_can",TRUE);
+	if (use_trash_can)
+		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
+	else
+		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
+
+	return 1;
+}
 
 // Refresh the directory size in the status bar
 long DirPanel::onCmdDirsizeRefresh(FXObject* sender,FXSelector,void*)
