@@ -9,28 +9,13 @@ class DirPanel : public FXVerticalFrame
     FXDECLARE(DirPanel)
     friend class XFileExplorer;
 	friend class FilePanel;
+	friend class PathLinker;
 protected:
-    FXIcon	*attricon;
-    FXIcon 	*archicon;
-    FXIcon 	*sorticon;
-    FXIcon	*newfoldericon;
-    FXIcon	*delicon;
-	FXIcon	*copyicon;
-	FXIcon	*cuticon;
-	FXIcon	*pasteicon;
-	FXIcon	*mapicon;
-	FXIcon	*unmapicon;
-	FXIcon	*xtermicon;
-	FXIcon	*symlinkicon;
-	FXIcon	*renameicon;
-	FXIcon	*moveicon;
-	FXIcon	*exptreeicon;
-	FXIcon	*expfoldericon;
-	FXIcon	*colltreeicon;
-	FXIcon	*collfoldericon;
 	DirList	*list;
 	FXPacker *statusbar;
     FXLabel	*status;
+	FXString homelocation;
+	FXString trashlocation;
 
 public:
 DirPanel(FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listforecolor=FXRGB(0,0,0),FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
@@ -52,6 +37,7 @@ DirPanel(FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listfor
 		ID_DIR_RENAME,
 		ID_DIR_SYMLINK,
 		ID_DIR_DELETE,
+		ID_DIR_TRASH,
 		ID_NEW_DIR,
 		ID_XTERM,
 		ID_COPY_CLP,
@@ -78,23 +64,26 @@ public:
 	long onCmdProperties(FXObject*,FXSelector,void*);
 	long onCmdAddToArch(FXObject*,FXSelector,void*);
 	long onCmdDirMan(FXObject*,FXSelector,void*);
-	long onCmdDirDel(FXObject*,FXSelector,void*);
+	long onCmdDirDelete(FXObject*,FXSelector,void*);
+	long onCmdDirTrash(FXObject*,FXSelector,void*);
 	long onCmdNewDir(FXObject*,FXSelector,void*);
 	long onCmdXTerm(FXObject*,FXSelector,void*);
 	long onCmdClp(FXObject*,FXSelector,void*);
 	long onCmdPaste(FXObject*,FXSelector,void*);
-	long onUpdPaste(FXObject* o,FXSelector,void*);
-	long onCmdDirectory(FXObject*,FXSelector,void* ptr);
-	long onCmdToggleTree(FXObject* sender,FXSelector sel,void* ptr);
-	long onCmdDirsizeRefresh(FXObject* sender,FXSelector,void*);
-	long onUpdToggleTree(FXObject* sender,FXSelector sel,void* ptr);
-	long onUpdMount(FXObject* o,FXSelector sel,void*);
-	long onUpdUnmount(FXObject* o,FXSelector sel,void*);
-	long onUpdMenu(FXObject* o,FXSelector,void*);
-	long onUpdTitle(FXObject* sender,FXSelector,void*);
-	long onUpdStatus(FXObject* sender,FXSelector,void*);
-	long onExpand(FXObject*,FXSelector,void* ptr);
-	long onCmdSortReverse(FXObject*,FXSelector,void* ptr);
+	long onUpdPaste(FXObject*,FXSelector,void*);
+	long onCmdDirectory(FXObject*,FXSelector,void*);
+	long onCmdToggleTree(FXObject*,FXSelector sel,void*);
+	long onCmdDirsizeRefresh(FXObject*,FXSelector,void*);
+	long onUpdToggleTree(FXObject*,FXSelector,void*);
+	long onUpdMount(FXObject*,FXSelector,void*);
+	long onUpdUnmount(FXObject*,FXSelector,void*);
+	long onUpdMenu(FXObject*,FXSelector,void*);
+	long onUpdDirTrash(FXObject*,FXSelector,void*);
+	long onUpdDirDelete(FXObject*,FXSelector,void*);
+	long onUpdTitle(FXObject*,FXSelector,void*);
+	long onUpdStatus(FXObject*,FXSelector,void*);
+	long onExpand(FXObject*,FXSelector,void*);
+	long onCmdSortReverse(FXObject*,FXSelector,void*);
 #if defined(linux)
 	long onCmdMount(FXObject*,FXSelector sel,void*);
 #endif
