@@ -25,9 +25,9 @@
 #include <alloca.h>
 #endif
 
-#include <fox-1.4/fx.h>
-#include <fox-1.4/fxkeys.h>
-#include <fox-1.4/FXPNGIcon.h>
+#include <fox-1.6/fx.h>
+#include <fox-1.6/fxkeys.h>
+#include <fox-1.6/FXPNGIcon.h>
 
 #include "xfedefs.h"
 #include "icons.h"
@@ -36,6 +36,7 @@
 #include "MessageBox.h"
 #include "CommandWindow.h"
 
+
 // Global variables
 extern FXMainWindow *mainWindow;
 #if defined(linux)
@@ -43,8 +44,8 @@ extern FXStringDict* mtdevices;
 extern FXStringDict* updevices;
 #endif
 
-// Timeout for stat functions (seconds)
-#define TIMEOUT 5
+// Startup time (seconds)
+#define STARTUP_TIME 3
 
 // Delay before the progress bar should be shown (ms)
 #define SHOW_PBAR_DELAY 1000
@@ -53,207 +54,96 @@ extern FXStringDict* updevices;
 #define PDIALOG_WIDTH 150
 
 
-// Replacement of the stat function with a timeout
-int statout(const char *filename, struct stat *buf)
+// Replacement of the stat function
+int statrep(const char *filename, struct stat *buf)
 {
 #if defined(linux)
+
+	static int ret;
+
 	// It's a mount point
 	if(mtdevices->find(filename))
 	{
-		// Mount point is up and is NFS or SMB
-		if(::streq(updevices->find(filename),"up")
-		   && (::streq(mtdevices->find(filename),"nfs") || ::streq(mtdevices->find(filename),"smbfs")))
-		{
-			int pid, ret;
-			time_t t0, t;
-	
-			// Create child process
-			pid = fork();
-    		if (pid == -1)
-        		return -1;
-    
-			if (pid == 0)
-    		{
-        		// Here, we are running as the child process!
-				ret=stat(filename,buf);
-				exit(ret);
-    		}
-    		else
-    		{
-        		// Here, we are running as the parent process!
-    			time(&t0);
-				while (1)
-				{
-					if ( (waitpid(pid,&ret,WNOHANG)==0 ) )
-					{
-						// Child is still running, wait
-						time(&t);
-				
-						// Timeout exceeded, abort
-						if (difftime(t,t0)>TIMEOUT)
-						{
-							kill(pid,SIGKILL);
-							waitpid(pid,&ret,WNOHANG); // Avoids zombies
-							return -1;
-						}
-					}
-					else
-					{
-						// Child has finished
-						if (ret==0)
-						{	
-							ret=stat(filename,buf);
-							return ret;
-						}
-						else
-							return -1;
-					}
-				}
-			}
-		}
 		// Mount point is down
-		else if(::streq(updevices->find(filename),"down"))
+		if(::streq(updevices->find(filename),"down"))
 			return -1;
 		
-		// Other mount point
+		// Mount point is up
 		else
-			return stat(filename,buf);		
+		{
+			ret=stat(filename,buf);
+			if (ret==-1)
+			{
+				updevices->remove(filename);
+				updevices->insert(filename,"down");
+			}
+			return ret;
+		}
 	}
 		
 	// It's not a mount point
 	else
 #endif
-	return stat(filename,buf);
+		return stat(filename,buf);
 }
 
-// Replacement of the lstat function with a timeout
-int lstatout(const char *filename, struct stat *buf)
+
+// Replacement of the lstat function
+int lstatrep(const char *filename, struct stat *buf)
 {
 #if defined(linux)
+
+	static int ret;
+
 	// It's a mount point
 	if(mtdevices->find(filename))
 	{
-		// Mount point is NFS or SMB
-		if(::streq(updevices->find(filename),"up")
-		   && (::streq(mtdevices->find(filename),"nfs") || ::streq(mtdevices->find(filename),"smbfs")))
-		{
-			int pid, ret;
-			time_t t0, t;
-	
-			// Create child process
-			pid = fork();
-    		if (pid == -1)
-       			return -1;
-    
-			if (pid == 0)
-    		{
-        		// Here, we are running as the child process!
-				ret=lstat(filename,buf);
-				exit(ret);
-    		}
-    		else
-    		{
-        		// Here, we are running as the parent process!
-				time(&t0);
-				while (1)
-				{
-					if ( (waitpid(pid,&ret,WNOHANG)==0 ) )
-					{
-						// Child is still running, wait
-						time(&t);
-				
-						// Timeout exceeded, abort
-						if (difftime(t,t0)>TIMEOUT)
-						{
-							kill(pid,SIGKILL);
-							waitpid(pid,&ret,WNOHANG); // Avoids zombies
-							return -1;
-						}
-					}
-					else
-					{
-						// Child has finished
-						if (ret==0)
-						{	
-							ret=lstat(filename,buf);
-							return ret;
-						}
-						else
-							return -1;
-					}
-				}
-			}
-		}
 		// Mount point is down
-		else if(::streq(updevices->find(filename),"down"))
+		if(::streq(updevices->find(filename),"down"))
 			return -1;
 		
-		// Other mount point
+		// Mount point is up
 		else
-			return lstat(filename,buf);		
+		{
+			ret=lstat(filename,buf);		
+			if (ret==-1)
+			{
+				updevices->remove(filename);
+				updevices->insert(filename,"down");
+			}
+			return ret;
+		}
 	}
 		
 	// It's not a mount point
 	else
 #endif
-	return lstat(filename,buf);
+		return lstat(filename,buf);
 }
 
 
 #if defined(linux)
 // Stat function used to test if a mount point is up or down
-int mtlstat(const char *filename, struct stat *buf)
+// Actually, this is simply the lstat() function
+int lstatmt(const char *filename, struct stat *buf)
 {
-	int pid, ret;
-	time_t t0, t;
-	
-	// Create child process
-	pid = fork();
-    if (pid == -1)
-       	return -1;
-    
-	if (pid == 0)
-    {
-        // Here, we are running as the child process!
-		ret=lstat(filename,buf);
-		exit(ret);
-    }
-    else
-    {
-        // Here, we are running as the parent process!
-		time(&t0);
-		while (1)
-		{
-			if ( (waitpid(pid,&ret,WNOHANG)==0 ) )
-			{
-				// Child is still running, wait
-				time(&t);
-				
-				// Timeout exceeded, abort
-				if (difftime(t,t0)>TIMEOUT)
-				{
-					kill(pid,SIGKILL);
-					waitpid(pid,&ret,WNOHANG); // Avoids zombies
-					return -1;
-				}
-			}
-			else
-			{
-				// Child has finished
-				if (ret==0)
-				{	
-					ret=lstat(filename,buf);
-					return ret;
-				}
-				else
-					return -1;
-			}
-		}
-	}
+	return lstat(filename,buf);
 }
 #endif
 
 
+// Run a command and simulate a startup time
+void runcmd(FXString cmd)
+{
+	// Run the command in background
+	cmd += " &";
+	system(cmd.text());
+	
+	// Very ugly simulation of a startup time!!!
+	sleep(STARTUP_TIME);
+}
+
+
 // Safe strcpy function (Public domain, by C.B. Falconer)
 // The destination string is always null terminated
 // Size sz must be equal to strlen(src)+1
@@ -347,7 +237,7 @@ unsigned long long dirsize(const char *path)
 			continue;
 #endif
 		
-		ret=lstatout(buf,&statbuf);
+		ret=lstatrep(buf,&statbuf);
 		if(ret>=0)
 		{
 			if(!S_ISDIR(statbuf.st_mode))
@@ -355,7 +245,7 @@ unsigned long long dirsize(const char *path)
 		}
 	}
 	if(closedir(dp)<0)
-        fprintf(stderr,"Cannot close directory %s\n", path);
+        fprintf(stderr,_("Cannot close directory %s\n"), path);
 	return dsize;
 }
 
@@ -369,7 +259,7 @@ unsigned long long pathsize(const char *path)
 	unsigned long long dsize;
 	int ret;
 
-	ret=lstatout(path,&statbuf);
+	ret=lstatrep(path,&statbuf);
 	if(ret<0)
         return 0;
     dsize = (unsigned long long) statbuf.st_size;
@@ -401,7 +291,7 @@ unsigned long long pathsize(const char *path)
     ptr[-1]='\0'; // ??
 	
     if(closedir(dp)<0)
-        fprintf(stderr,"Cannot close directory %s\n", path);
+        fprintf(stderr,_("Cannot close directory %s\n"), path);
     return dsize;
 }
 
@@ -454,7 +344,27 @@ FXString hSize(FXchar* size)
 // Remove terminating '/' on a path string to simplify a file or directory path
 // Thus '/bla/bla////' becomes '/bla/bla'
 // Special case : '/' stays to '/'
-// And then return the absolute path, based on the current directory path
+FXString cleanPath(const FXString path)
+{
+	FXString in=path, out=path;
+	while (1)
+	{
+		if (in[in.length()-1]=='/' & in.length()!=1)
+		{
+			out=in.trunc(in.length()-1);
+			in=out;
+		}
+		else
+			break;
+	}
+
+	return (out);
+}
+
+// Return the absolute path, based on the current directory path
+// Remove terminating '/' on a path string to simplify a file or directory path
+// Thus '/bla/bla////' becomes '/bla/bla'
+// Special case : '/' stays to '/'
 FXString filePath(const FXString path)
 {
 	FXString in=path, out=path;
@@ -468,7 +378,7 @@ FXString filePath(const FXString path)
 		else
 			break;
 	}
-	FXString dir=FXFile::getCurrentDirectory();
+	FXString dir=FXSystem::getCurrentDirectory();
 
 	// If absolute path
 	if(ISPATHSEP(out[0]))
@@ -477,10 +387,10 @@ FXString filePath(const FXString path)
 		return (dir+PATHSEPSTRING+out);
 }
 
+// Return the absolute path, based on the specified directory path
 // Remove terminating '/' on a path string to simplify a file or directory path
 // Thus '/bla/bla////' becomes '/bla/bla'
 // Special case : '/' stays to '/'
-// And then return the absolute path, based on the specified directory path
 FXString filePath(const FXString path, const FXString dir)
 {
 	FXString in=path, out=path;
@@ -502,17 +412,17 @@ FXString filePath(const FXString path, const FXString dir)
 }
 
 
-// Obtain a unique file name based on the current time stamp, such as : filename__YYYYMMDD-HH:MM:SS-sec
+// Obtain a unique file name based on the current time stamp, such as : filename__TRASH__tv_sec-tv_usec
 // If filename is a path name, only the modified filename is returned
 // Used for file deletion to trash can
 FXString stampname(const FXString filename)
 {
 	struct timeval tv;
-	char stamp[32];
+	char stamp[48];
 	
 	gettimeofday(&tv,NULL);
-	snprintf(stamp,sizeof(stamp)-1,"__%s-%ld",FXFile::time("%Y%m%d-%H:%M:%S",tv.tv_sec).text(),tv.tv_usec);
-	return (FXFile::name(filename)+stamp);
+	snprintf(stamp,sizeof(stamp)-1,"__%s__%ld-%ld",_("TRASH"),tv.tv_sec,tv.tv_usec);
+	return (FXPath::name(filename)+stamp);
 }
 
 
@@ -541,21 +451,21 @@ FXint isEmptyDir(const FXString directory)
 FXbool exists(const FXString& file)
 {
   	struct stat status;
-  	return !file.empty() && (lstatout(file.text(),&status)==0);
+  	return !file.empty() && (lstatrep(file.text(),&status)==0);
 }
 
 // Check if the file represents a directory
 FXbool isDirectory(const FXString& file)
 {
   	struct stat status;
-  	return !file.empty() && (statout(file.text(),&status)==0) && S_ISDIR(status.st_mode);
+  	return !file.empty() && (statrep(file.text(),&status)==0) && S_ISDIR(status.st_mode);
 }
 
 // Check if file represents a file
 FXbool isFile(const FXString& file)
 {
   	struct stat status;
-  	return !file.empty() && (statout(file.text(),&status)==0) && S_ISREG(status.st_mode);
+  	return !file.empty() && (statrep(file.text(),&status)==0) && S_ISREG(status.st_mode);
 }
 
 // Check if current user is member of gid
@@ -594,7 +504,7 @@ FXbool isWritable(const FXString& file)
 	FXuint uid=getuid();
 	
 	// File exists and can be stated
-	if (!file.empty() && (statout(file.text(),&status)==0))
+	if (!file.empty() && (statrep(file.text(),&status)==0))
 	{
 		// We are root
 		if (uid==0)
@@ -643,7 +553,7 @@ FXbool isLWritable(const FXString& file)
 	FXuint uid=getuid();
 	
 	// File or link exists and can be stated
-	if (!file.empty() && (lstatout(file.text(),&status)==0))
+	if (!file.empty() && (lstatrep(file.text(),&status)==0))
 	{
 		// We are root
 		if (uid==0)
@@ -684,6 +594,57 @@ FXbool isLWritable(const FXString& file)
 		return FALSE;
 }
 
+
+// Check if the file or the link refered file is readable
+// Doesn't use the standard FOX function because of the stat timeout 
+FXbool isReadable(const FXString& file)
+{
+  	struct stat status;
+	FXuint uid=getuid();
+	
+	// File exists and can be stated
+	if (!file.empty() && (statrep(file.text(),&status)==0))
+	{
+		// We are root
+		if (uid==0)
+		{
+			return TRUE;
+		}
+		// We are owner of the file
+		else if (uid==status.st_uid)
+		{
+			// The file is readable
+			if (status.st_mode & S_IRUSR)
+				return TRUE;
+			else
+				return FALSE;
+		}
+		// We are in the group of the file
+		else if (isGroupMember(status.st_gid))
+		{
+			// The file is readable
+			if (status.st_mode & S_IRGRP)
+				return TRUE;
+			else
+				return FALSE;
+		}
+		// We are in others
+		else
+		{
+			// The file is readable
+			if (status.st_mode & S_IROTH)
+				return TRUE;
+			else
+				return FALSE;
+		}
+	}	
+	
+	// File doesn't exist or cannot be stated
+	else
+		return FALSE;
+}
+
+
 // Check if the file or the link refered file is readable AND executable
 // Function used to test if we can enter a directory
 // Doesn't use the standard FOX function because of the stat timeout 
@@ -693,7 +654,7 @@ FXbool isReadExecutable(const FXString& file)
 	FXuint uid=getuid();
 	
 	// File exists and can be stated
-	if (!file.empty() && (statout(file.text(),&status)==0))
+	if (!file.empty() && (statrep(file.text(),&status)==0))
 	{
 		// We are root
 		if (uid==0)
@@ -738,16 +699,35 @@ FXbool isReadExecutable(const FXString& file)
 FXbool isLink(const FXString& file)
 {
   	struct stat status;
-  	return !file.empty() && (lstatout(file.text(),&status)==0) && S_ISLNK(status.st_mode);
+  	return !file.empty() && (lstatrep(file.text(),&status)==0) && S_ISLNK(status.st_mode);
 }
 
 // Get file info
 FXbool info(const FXString& file,struct stat& inf)
 {
-  	return !file.empty() && (statout(file.text(),&inf)==0);
+  	return !file.empty() && (statrep(file.text(),&inf)==0);
 }
 
-// Read symbolic link
+// Return permissions string
+// (the FOX function FXSystem::modeString() seems to use another format for the mode field) 
+FXString permissions(FXuint mode)
+{
+	FXchar result[11];
+	result[0]=S_ISLNK(mode) ? 'l' : S_ISREG(mode) ? '-' : S_ISDIR(mode) ? 'd' : S_ISCHR(mode) ? 'c' : S_ISBLK(mode) ? 'b' : S_ISFIFO(mode) ? 'p' : S_ISSOCK(mode) ? 's' : '?';
+	result[1]=(mode&S_IRUSR) ? 'r' : '-';
+	result[2]=(mode&S_IWUSR) ? 'w' : '-';
+	result[3]=(mode&S_ISUID) ? 's' : (mode&S_IXUSR) ? 'x' : '-';
+	result[4]=(mode&S_IRGRP) ? 'r' : '-';
+	result[5]=(mode&S_IWGRP) ? 'w' : '-';
+	result[6]=(mode&S_ISGID) ? 's' : (mode&S_IXGRP) ? 'x' : '-';
+	result[7]=(mode&S_IROTH) ? 'r' : '-';
+	result[8]=(mode&S_IWOTH) ? 'w' : '-';
+	result[9]=(mode&S_ISVTX) ? 't' : (mode&S_IXOTH) ? 'x' : '-';
+	result[10]=0;
+	return result;
+}
+
+  // Read symbolic link
 FXString readlink(const FXString& file)
 {
 	FXchar lnk[MAXPATHLEN+1];
@@ -766,7 +746,7 @@ FXbool identical(const FXString& file1,const FXString& file2)
 	if(file1!=file2)
 	{
     	struct stat stat1,stat2;
-    	return !::lstatout(file1.text(),&stat1) && !::lstatout(file2.text(),&stat2) && stat1.st_ino==stat2.st_ino && stat1.st_dev==stat2.st_dev;
+    	return !::lstatrep(file1.text(),&stat1) && !::lstatrep(file2.text(),&stat2) && stat1.st_ino==stat2.st_ino && stat1.st_dev==stat2.st_dev;
     }
   	return TRUE;
 }
@@ -863,7 +843,7 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):FXDial
 			break;
 #endif
 
-		default: // Other : RENAME, SYMLINK, ARCHIVE, EXTRACT, RPM_INSTALL, RPM_UNINSTALL
+		default: // Other : RENAME, SYMLINK, ARCHIVE, EXTRACT, PKG_INSTALL, PKG_UNINSTALL
 			// Progress dialog not used
 			uplabel=NULL;
     		downlabel=NULL;
@@ -963,19 +943,19 @@ FXbool File::copyfile(const FXString& source, const FXString& target)
     FXString destfile;
 	unsigned char buffer[4096];
     struct stat status;
-    long nread,nwritten;
-	long size, nread_all=0;
+    long long nread,nwritten;
+	long long size, nread_all=0;
 	double pct=0;
     int src,dst;
     FXbool ok=FALSE;
 
     if((src=::open(source.text(),O_RDONLY))>=0)
     {
-        if(statout(source.text(),&status)==0)
+        if(statrep(source.text(),&status)==0)
         {
 			// If destination is a directory
 			if(::isDirectory(target))
-				destfile=target+PATHSEPSTRING+FXFile::name(source);
+				destfile=target+PATHSEPSTRING+FXPath::name(source);
 			else
 				destfile=target;
 				
@@ -988,7 +968,7 @@ FXbool File::copyfile(const FXString& source, const FXString& target)
                     nread=File::fullread(src,buffer,sizeof(buffer));
                     if(nread<0)
 					{
-						MessageBox::error(this,MBOX_OK,_("Error"),"%s",strerror(errno));									
+						MessageBox::error(this,BOX_OK,_("Error"),"%s",strerror(errno));									
                         goto err;
 					}
                     if(nread==0)
@@ -1024,7 +1004,7 @@ FXbool File::copyfile(const FXString& source, const FXString& target)
                     nwritten=File::fullwrite(dst,buffer,nread);
                     if(nwritten<0)
 					{
-						MessageBox::error(this,MBOX_OK,_("Error"),"%s",strerror(errno) );			
+						MessageBox::error(this,BOX_OK,_("Error"),"%s",strerror(errno) );
                         goto err;
 					}
                 }
@@ -1050,7 +1030,7 @@ FXbool File::copydir(const FXString& source,const FXString& target,struct stat&
 
 	// If destination is an existing directory
 	if(::isDirectory(target))
-		destfile=target+PATHSEPSTRING+FXFile::name(source);
+		destfile=target+PATHSEPSTRING+FXPath::name(source);
 	else
 		destfile=target;
 
@@ -1066,7 +1046,7 @@ FXbool File::copydir(const FXString& source,const FXString& target,struct stat&
         return FALSE;
 
     // Can we stat it
-    if(lstatout(destfile.text(),&status)!=0 || !S_ISDIR(status.st_mode))
+    if(lstatrep(destfile.text(),&status)!=0 || !S_ISDIR(status.st_mode))
         return FALSE;
 
     // Try open directory to copy
@@ -1103,15 +1083,14 @@ FXbool File::copydir(const FXString& source,const FXString& target,struct stat&
 				// Or a permission problem occured
 				else
 				{
-					FXPNGIcon icon(getApp(),errorIcon);
 					FXString str;
 					if (::isDirectory(oldchild))
 						str=_("Can't copy folder ") + oldchild + _(" : Permission denied");
 					else
 						str=_("Can't copy file ") + oldchild + _(" : Permission denied");
-       				MessageBox box(this,_("Error"),str,&icon,MBOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
+       				MessageBox box(this,_("Error"),str,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
 					FXuint answer=box.execute(PLACEMENT_SCREEN);
-					if(answer == MBOX_CLICKED_CANCEL)
+					if(answer == BOX_CLICKED_CANCEL)
 					{
                			closedir(dirp);
 						isCancelled=TRUE;
@@ -1136,11 +1115,11 @@ FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* in
     struct stat status1,status2;
 
     // Source file or directory does not exist
-    if(lstatout(source.text(),&status1)!=0)
+    if(lstatrep(source.text(),&status1)!=0)
         return FALSE;
 
     // If target is not a directory, remove it if allowed
-    if(lstatout(target.text(),&status2)==0)
+    if(lstatrep(target.text(),&status2)==0)
     {
         if(!S_ISDIR(status2.st_mode))
         {
@@ -1151,7 +1130,14 @@ FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* in
         }
     }
 
-    // Source is directory: copy recursively
+    // Source is not readable for the current user
+	if (!isReadable(source))
+	{
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is not readable"), source.text());
+		return FALSE;
+	}
+		
+	// Source is directory: copy recursively
     if(S_ISDIR(status1.st_mode))
         return File::copydir(source,target,status1,inodes);
 
@@ -1188,27 +1174,27 @@ FXbool File::copy(const FXString& source, const FXString& target, const FXbool c
 	// Source doesn't exist
 	if(!::exists(source))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
 		return FALSE;
 	}
 
 	// Source and target are identical
 	if (::identical(target,source))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
 		return FALSE;
 	}
 
 	// Target is an existing directory
 	if (::isDirectory(target))
-		targetfile=target+PATHSEPSTRING+FXFile::name(source);
+		targetfile=target+PATHSEPSTRING+FXPath::name(source);
 	else
 		targetfile=target;
 
 	// Source and target file are identical
 	if (::identical(targetfile,source))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Source %s is identical to target"), targetfile.text());			
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), targetfile.text());			
 		return FALSE;
 	}
 
@@ -1245,13 +1231,13 @@ FXbool File::copy(const FXString& source, const FXString& target, const FXbool c
        		}
 		}
 		if(!(overwrite | overwrite_all) | skip_all)
-			return FALSE;
+			return TRUE;
 
 		// Use of the standard C function to remove the target
 		// avoids to overwrite a non empty directory
 		if (::remove(targetfile.text())==-1)
 		{
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Cannot overwrite the non empty folder %s"), targetfile.text());			
+			MessageBox::error(this,BOX_OK,_("Error"),_("Cannot overwrite the non empty folder %s"), targetfile.text());			
 			return FALSE;
 		}
 	}
@@ -1268,7 +1254,7 @@ FXbool File::remove(const FXString& file)
     struct stat status;
 	static FXbool ISDIR=FALSE;
 
-    if(lstatout(file.text(),&status)==0)
+    if(lstatrep(file.text(),&status)==0)
     {
         // It is a directory
 		if(S_ISDIR(status.st_mode))
@@ -1292,7 +1278,7 @@ FXbool File::remove(const FXString& file)
 				// Set labels for progress dialog
 				FXString label=_("Delete folder :")+file;
 				uplabel->setText(label);
-				dirname=FXFile::directory(FXFile::absolute(file));
+				dirname=FXPath::directory(FXPath::absolute(file));
 				label=_("From : ")+dirname;
 				downlabel->setText(label);
 				getApp()->repaint();
@@ -1320,7 +1306,7 @@ FXbool File::remove(const FXString& file)
             }
 			if (rmdir(file.text())==-1)
 			{
-				MessageBox::error(this,MBOX_OK,_("Error"),_("Cannot delete directory %s"), file.text());			
+				MessageBox::error(this,BOX_OK,_("Error"),_("Cannot delete directory %s"), file.text());			
 				return FALSE;
 			}
 			else
@@ -1341,7 +1327,7 @@ FXbool File::remove(const FXString& file)
 				// Set labels for progress dialog
 				FXString label=_("Delete : ")+file;
 				uplabel->setText(label);
-				dirname=FXFile::directory(FXFile::absolute(file));
+				dirname=FXPath::directory(FXPath::absolute(file));
 				label=_("From : ")+dirname;
 				downlabel->setText(label);
 				getApp()->repaint();
@@ -1352,7 +1338,7 @@ FXbool File::remove(const FXString& file)
 			}
 			if (unlink(file.text())==-1)
 			{
-				MessageBox::error(this,MBOX_OK,_("Error"),_("Cannot delete file %s"), file.text());			
+				MessageBox::error(this,BOX_OK,_("Error"),_("Cannot delete file %s"), file.text());			
 				return FALSE;
 			}
 			else
@@ -1369,14 +1355,14 @@ FXbool File::rename(const FXString& source, const FXString& target)
 	// Source doesn't exist
     if(!::exists(source))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
 		return FALSE;
 	}
 			
 	// Source and target are identical
 	if (::identical(target,source))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
 		return FALSE;
 	}
 
@@ -1407,7 +1393,7 @@ FXbool File::rename(const FXString& source, const FXString& target)
        		}
 		}
 		if(!(overwrite | overwrite_all) | skip_all)
-			return FALSE;
+			return TRUE;
 	}
        		
 	// Rename file using the standard C function
@@ -1416,7 +1402,7 @@ FXbool File::rename(const FXString& source, const FXString& target)
 		return TRUE;
 	if(errno!=EXDEV)
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Cannot rename to target %s"), target.text());	
+		MessageBox::error(this,BOX_OK,_("Error"),_("Cannot rename to target %s"), target.text());	
 		return FALSE;
 	}
 
@@ -1435,28 +1421,28 @@ FXbool File::move(const FXString& source,const FXString& target)
 	// Source doesn't exist
 	if(!::exists(source))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
 		return FALSE;
 	}
 
 	// Source and target are identical
 	if (identical(target,source))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
 		return FALSE;
 	}
 
 	// Target is an existing directory
 	FXString targetfile;
 	if (::isDirectory(target))
-		targetfile=target+PATHSEPSTRING+FXFile::name(source);
+		targetfile=target+PATHSEPSTRING+FXPath::name(source);
 	else
 		targetfile=target;
 
 	// Source and target file are identical
 	if (::identical(targetfile,source))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
 		return FALSE;
 	}
 
@@ -1502,7 +1488,7 @@ FXbool File::move(const FXString& source,const FXString& target)
        		}
 		}
 		if(!(overwrite | overwrite_all) | skip_all)
-			return FALSE;
+			return TRUE;
 	}
 
 	// Set the progress to 100% for move file operation
@@ -1515,7 +1501,7 @@ FXbool File::move(const FXString& source,const FXString& target)
 		return TRUE;
 	if(errno!=EXDEV)
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Cannot rename to target %s"), targetfile.text());	
+		MessageBox::error(this,BOX_OK,_("Error"),_("Cannot rename to target %s"), targetfile.text());	
 		return FALSE;
 	}
 
@@ -1534,14 +1520,14 @@ FXbool File::symlink(const FXString& source,const FXString& target)
 	// Source doesn't exist
     if(!::exists(source))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
 		return FALSE;
 	}
 			
 	// Source and target are identical
 	if (::identical(target,source))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
+		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
 		return FALSE;
 	}
 
@@ -1572,7 +1558,7 @@ FXbool File::symlink(const FXString& source,const FXString& target)
        		}
 		}
 		if(!(overwrite | overwrite_all) | skip_all)
-			return FALSE;
+			return TRUE;
 	}
     
 	// Create symbolic link using the standard C function
@@ -1581,7 +1567,7 @@ FXbool File::symlink(const FXString& source,const FXString& target)
 		return TRUE;
 	else
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),"%s",strerror(errno));
+		MessageBox::error(this,BOX_OK,_("Error"),"%s",strerror(errno));
 		return FALSE;
 	}		
 }
@@ -1591,14 +1577,14 @@ FXbool File::symlink(const FXString& source,const FXString& target)
 // Note : the variable file returns the last processed file
 // It can be different from the initial path, if recursive chmod is used
 // (Used to fill an error message, if needed) 
-int File::chmod(char *path, char *file, mode_t mode, FXbool rec, const FXbool dironly)
-{		
+int File::chmod(char *path, char *file, mode_t mode, FXbool rec, const FXbool dironly, const FXbool fileonly)
+{			
     struct stat stats;
 
 	// Initialise the file variable with the initial path
 	strlcpy(file, path, strlen(path)+1);
 
-    if (lstatout(path, &stats)) //if it doesn't exist
+    if (lstatrep(path, &stats)) //if it doesn't exist
         return -1;
 
     if (!S_ISDIR(stats.st_mode)) // file
@@ -1628,7 +1614,7 @@ int File::chmod(char *path, char *file, mode_t mode, FXbool rec, const FXbool di
     }
     else // directory
     {
-        if(rec == FALSE)
+		if(rec == FALSE && !fileonly)
         {
 			// Force timeout checking for progress dialog
 			checkTimeout();
@@ -1652,7 +1638,7 @@ int File::chmod(char *path, char *file, mode_t mode, FXbool rec, const FXbool di
 				return -1;
         }
         else
-            return rchmod(path,file,mode,dironly); // recursive change
+            return rchmod(path,file,mode,dironly,fileonly); // recursive change
     }
     return 0;
 
@@ -1660,14 +1646,14 @@ int File::chmod(char *path, char *file, mode_t mode, FXbool rec, const FXbool di
 
 
 // Recursive chmod for a directory
-int File::rchmod(char *path, char *file, mode_t mode, const FXbool dironly)
+int File::rchmod(char *path, char *file, mode_t mode, const FXbool dironly, const FXbool fileonly)
 {
     struct stat stats;
 
 	// Initialise the file variable with the initial path
 	strlcpy(file, path, strlen(path)+1);
 
-    if (lstatout(path, &stats)) //if it doesn't exist
+    if (lstatrep(path, &stats)) //if it doesn't exist
         return -1;
 
     if (!S_ISDIR(stats.st_mode)) // file
@@ -1696,7 +1682,7 @@ int File::rchmod(char *path, char *file, mode_t mode, const FXbool dironly)
         return ::chmod(path,mode);
     }
 
-    DIR *dir;
+	DIR *dir;
     struct dirent *entry;
     int i, pl = strlen(path);
 
@@ -1719,7 +1705,7 @@ int File::rchmod(char *path, char *file, mode_t mode, const FXbool dironly)
 
 			// Modify the file variable with the new path
 			strlcpy(file, path1, strlen(path1)+1);
-            if (rchmod(path1,file,mode,dironly))
+            if (rchmod(path1,file,mode,dironly,fileonly))
                 return -1;
         }
 	}
@@ -1727,7 +1713,10 @@ int File::rchmod(char *path, char *file, mode_t mode, const FXbool dironly)
     if (closedir(dir))
         return -1;
 
-    return ::chmod(path,mode);
+	if (fileonly)
+		return 0;
+	else
+		return ::chmod(path,mode);
 }
 
 
@@ -1735,14 +1724,14 @@ int File::rchmod(char *path, char *file, mode_t mode, const FXbool dironly)
 // Note : the variable file returns the last processed file
 // It can be different from the initial path, if recursive chmod is used
 // (Used to fill an error message, if needed) 
-int File::chown(char *path, char *file, uid_t uid, gid_t gid, const FXbool rec, const FXbool dironly)
+int File::chown(char *path, char *file, uid_t uid, gid_t gid, const FXbool rec, const FXbool dironly, const FXbool fileonly)
 {
     struct stat stats;
 
 	// Initialise the file variable with the initial path
 	strlcpy(file, path, strlen(path)+1);
 
-    if (lstatout(path, &stats)) //if it doesn't exist
+    if (lstatrep(path, &stats)) //if it doesn't exist
         return -1;
 
     if (!S_ISDIR(stats.st_mode)) // file
@@ -1772,8 +1761,8 @@ int File::chown(char *path, char *file, uid_t uid, gid_t gid, const FXbool rec,
             return -1;
     }
     else // directory
-    {
-        if(rec == FALSE)
+    {	
+		if(rec == FALSE && !fileonly)
         {
 			// Force timeout checking for progress dialog
 			checkTimeout();
@@ -1797,7 +1786,7 @@ int File::chown(char *path, char *file, uid_t uid, gid_t gid, const FXbool rec,
                 return -1;
         }
         else
-            if(rchown(path,file,uid,gid,dironly)) // recursive change
+            if(rchown(path,file,uid,gid,dironly,fileonly)) // recursive change
                 return -1;
     }
     return 0;
@@ -1806,14 +1795,14 @@ int File::chown(char *path, char *file, uid_t uid, gid_t gid, const FXbool rec,
 
 
 // Recursive chown for a directory
-int File::rchown(char *path, char *file, uid_t uid, gid_t gid, const FXbool dironly)
+int File::rchown(char *path, char *file, uid_t uid, gid_t gid, const FXbool dironly, const FXbool fileonly)
 {
     struct stat stats;
 
 	// Initialise the file variable with the initial path
 	strlcpy(file, path, strlen(path)+1);
 
-    if (lstatout(path, &stats)) //if it doesn't exist
+    if (lstatrep(path, &stats)) //if it doesn't exist
         return -1;
 
     if (!S_ISDIR(stats.st_mode)) // file
@@ -1841,7 +1830,7 @@ int File::rchown(char *path, char *file, uid_t uid, gid_t gid, const FXbool diro
 
 		return ::chown(path,uid,gid);
     }
-
+	
     DIR *dir;
     struct dirent *entry;
     int i, pl = strlen(path);
@@ -1862,17 +1851,17 @@ int File::rchown(char *path, char *file, uid_t uid, gid_t gid, const FXbool diro
                 path1[pl1++] = '/';
             strlcpy(path1+pl1, entry->d_name, strlen(entry->d_name)+1);
 			strlcpy(file, path1, strlen(path1)+1);
-            if (rchown(path1,file,uid,gid,dironly))
+            if (rchown(path1,file,uid,gid,dironly,fileonly))
                 return -1;
         }
 
     if (closedir(dir))
         return -1;
-
-    if(::chown(path,uid,gid))
-        return -1;
-
-    return 0;
+ 
+	if (fileonly)
+		return 0;
+	else
+		return ::chown(path,uid,gid);
 }
 
 
@@ -1922,7 +1911,7 @@ int File::archive(const FXString name, const FXString cmd)
        		}
 		}
 		if(!(overwrite | overwrite_all) | skip_all)
-			return FALSE;
+			return TRUE;
 	}
 
     // Make and show command window
@@ -1962,7 +1951,7 @@ int File::mount(const FXString dir, const FXString msg, const FXString cmd, cons
 	FILE *pcmd=popen(cmd.text(),"r");
 	if(!pcmd)
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Failed command : %s"),cmd.text());
+		MessageBox::error(this,BOX_OK,_("Error"),_("Failed command : %s"),cmd.text());
 		return -1;
 	}
 
@@ -1976,7 +1965,7 @@ int File::mount(const FXString dir, const FXString msg, const FXString cmd, cons
 	// Close the stream
 	if(pclose(pcmd))
 	{
-		MessageBox::error(this,MBOX_OK,_("Error"),"%s",text);
+		MessageBox::error(this,BOX_OK,_("Error"),"%s",text);
 		return -1;
 	}
 	// Hide progress dialog
@@ -1986,45 +1975,43 @@ int File::mount(const FXString dir, const FXString msg, const FXString cmd, cons
 	if(mount_messages)
 	{
 		if (op==MOUNT)
-			MessageBox::information(this,MBOX_OK,_("Success"),_("Folder %s was successfully mounted."),dir.text());
+			MessageBox::information(this,BOX_OK,_("Success"),_("Folder %s was successfully mounted."),dir.text());
 		else
-			MessageBox::information(this,MBOX_OK,_("Success"),_("Folder %s was successfully unmounted."),dir.text());
+			MessageBox::information(this,BOX_OK,_("Success"),_("Folder %s was successfully unmounted."),dir.text());
 	}
 	return 1;
 }
 
 
-// Install / Upgrade RPM package
-int File::rpmInstall(const FXString name, const FXString cmd)
+// Install / Upgrade package
+int File::pkgInstall(const FXString name, const FXString cmd)
 {
     // Make and show command window
-	CommandWindow *cmdwin=new CommandWindow(getApp(),_("Install/Upgrade RPM"),cmd,10,80);			
+	CommandWindow *cmdwin=new CommandWindow(getApp(),_("Install/Upgrade package"),cmd,10,80);			
 	cmdwin->create();
 
+	FXString msg=_("Installing package : ") + name + "\n"; 
+	cmdwin->appendText(msg.text());
+
 	// The command window object deletes itself after closing the window!
 
     return 1;
 }
 
-// Uninstall RPM package
-int File::rpmUninstall(const FXString name, const FXString cmd)
+// Uninstall package
+int File::pkgUninstall(const FXString name, const FXString cmd)
 {
     // Make and show command window
-	CommandWindow *cmdwin=new CommandWindow(getApp(),_("Uninstall RPM"),cmd,10,80);			
+	CommandWindow *cmdwin=new CommandWindow(getApp(),_("Uninstall package"),cmd,10,80);			
 	cmdwin->create();
 	
-	// Add a message if necessary
-	if (cmdwin->getLength()==0)
-	{
-		FXString msg=_("Package ") + name + _(" uninstalled successfully."); 
-		cmdwin->appendText(msg.text());
-	}
+	FXString msg=_("Uninstalling package : ") + name + "\n"; 
+	cmdwin->appendText(msg.text());
 
 	// The command window object deletes itself after closing the window!
 
     return 1;
 }
-
 #endif
 
 
