@@ -10,20 +10,23 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <dirent.h>
-#include <fox-1.4/fx.h>
+#include <fox-1.6/fx.h>
 
+
+int statrep(const char *filename, struct stat *buf);
+int lstatrep(const char *filename, struct stat *buf);
+#ifdef linux
+int lstatmt(const char *filename, struct stat *buf);
+#endif
+void runcmd(FXString cmd);
 size_t strlcpy(char *dst, const char *src, size_t sz);
 size_t strlcat(char *dst, const char *src, size_t sz);
 void strlow(char *str);
 int streq(const FXchar *a, const FXchar *b);
-int statout(const char *filename, struct stat *buf);
-int lstatout(const char *filename, struct stat *buf);
-#ifdef linux
-int mtlstat(const char *filename, struct stat *buf);
-#endif
 unsigned long long dirsize(const char *path);
 unsigned long long pathsize(const char *path);
 FXString hSize(FXchar* size);
+FXString cleanPath(const FXString path);
 FXString filePath(const FXString path);
 FXString filePath(const FXString path, const FXString dir);
 FXString stampname(const FXString filename);
@@ -34,9 +37,11 @@ FXbool isFile(const FXString& file);
 FXbool isGroupMember(gid_t gid);
 FXbool isWritable(const FXString& file);
 FXbool isLWritable(const FXString& file);
+FXbool isReadable(const FXString& file);
 FXbool isReadExecutable(const FXString& file);
 FXbool isLink(const FXString& file);
 FXbool info(const FXString& file,struct stat& inf);
+FXString permissions(FXuint mode);
 FXString readlink(const FXString& file);
 FXbool identical(const FXString& file1,const FXString& file2);
 
@@ -53,8 +58,8 @@ enum
 	EXTRACT,
 	ARCHIVE,
 #if defined(linux)
-	RPM_INSTALL,
-	RPM_UNINSTALL,
+	PKG_INSTALL,
+	PKG_UNINSTALL,
 	MOUNT,
 	UNMOUNT
 #endif
@@ -77,8 +82,8 @@ protected:
     FXbool copyfile(const FXString& source, const FXString& target);
 	FXbool copyrec(const FXString& source,const FXString& target,inodelist* inodes);
     FXbool copydir(const FXString& source,const FXString& target,struct stat& parentstatus,inodelist* inodes);
-    int rchmod(char *path, char *file, mode_t mode, const FXbool dironly);
-    int rchown(char *path, char *file, uid_t uid, gid_t gid, const FXbool dironly);
+    int rchmod(char *path, char *file, mode_t mode, const FXbool dironly, const FXbool fileonly);
+    int rchown(char *path, char *file, uid_t uid, gid_t gid, const FXbool dironly, const FXbool fileonly);
     FXLabel *uplabel;
     FXLabel *downlabel;
     FXProgressBar *pbar;
@@ -109,15 +114,15 @@ public:
     FXbool symlink(const FXString& source, const FXString& target);
     FXbool remove(const FXString& file);
 
-    int chmod(char *path, char *file, mode_t mode, const FXbool rec, const FXbool dironly=FALSE);
-    int chown(char *path, char *file, uid_t uid, gid_t gid, const FXbool rec, const FXbool dironly=FALSE);
+    int chmod(char *path, char *file, mode_t mode, const FXbool rec, const FXbool dironly=FALSE, const FXbool fileonly=FALSE);
+    int chown(char *path, char *file, uid_t uid, gid_t gid, const FXbool rec, const FXbool dironly=FALSE, const FXbool fileonly=FALSE);
 	int extract(const FXString name, const FXString dir,const FXString cmd);
 	int archive(const FXString name, const FXString cmd);
 
 #if defined(linux)
 	int mount(const FXString dir, const FXString msg, const FXString cmd,const  unsigned int op);
-	int rpmInstall(const FXString name, const FXString cmd);
-	int rpmUninstall(const FXString name, const FXString cmd);
+	int pkgInstall(const FXString name, const FXString cmd);
+	int pkgUninstall(const FXString name, const FXString cmd);
 #endif
 	long onCmdCancel(FXObject*, FXSelector,void*);
     long onTimeout(FXObject*,FXSelector,void*);
