@@ -2,14 +2,15 @@
 #include "config.h"
 #include "i18n.h"
 
-#include <fox-1.4/fx.h>
-#include <fox-1.4/fxkeys.h>
-#include <fox-1.4/FXPNGIcon.h>
+#include <fox-1.6/fx.h>
+#include <fox-1.6/fxkeys.h>
+#include <fox-1.6/FXPNGIcon.h>
 
 #include "File.h"
 #include "FileList.h"
 #include "DirBox.h"
 #include "FileDialog.h"
+#include "DirHistBox.h"
 #include "icons.h"
 
 #define FILELISTMASK (ICONLIST_EXTENDEDSELECT|ICONLIST_SINGLESELECT|ICONLIST_BROWSESELECT|ICONLIST_MULTIPLESELECT)
@@ -23,9 +24,17 @@ FXDEFMAP(FileSelector) FileSelectorMap[]={
             FXMAPFUNC(SEL_DOUBLECLICKED,FileSelector::ID_FILELIST,FileSelector::onCmdItemDblClicked),
             FXMAPFUNC(SEL_SELECTED,FileSelector::ID_FILELIST,FileSelector::onCmdItemSelected),
             FXMAPFUNC(SEL_DESELECTED,FileSelector::ID_FILELIST,FileSelector::onCmdItemDeselected),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIRECTORY_UP,FileSelector::onCmdDirectoryUp),
-            FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIRECTORY_UP,FileSelector::onUpdDirectoryUp),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIRTREE,FileSelector::onCmdDirTree),
+            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_UP,FileSelector::onCmdDirUp),
+            FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_UP,FileSelector::onUpdDirUp),
+            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_BACK,FileSelector::onCmdDirBack),
+			FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_BACK,FileSelector::onUpdDirBack),
+            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_FORWARD,FileSelector::onCmdDirForward),
+			FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_FORWARD,FileSelector::onUpdDirForward),
+            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_BACK_HIST,FileSelector::onCmdDirBackHist),
+			FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_BACK_HIST,FileSelector::onUpdDirBackHist),
+            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_FORWARD_HIST,FileSelector::onCmdDirForwardHist),
+			FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_FORWARD_HIST,FileSelector::onUpdDirForwardHist),
+            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_TREE,FileSelector::onCmdDirTree),
             FXMAPFUNC(SEL_COMMAND,FileSelector::ID_HOME,FileSelector::onCmdHome),
             FXMAPFUNC(SEL_COMMAND,FileSelector::ID_WORK,FileSelector::onCmdWork),
         };
@@ -45,48 +54,44 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
 	FXAccelTable *table=getShell()->getAccelTable();
     target=tgt;
     message=sel;
-    FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING, 0,0);
-    FXMatrix *fields=new FXMatrix(this,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
+    FXHorizontalFrame* buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING, 0,0);
+    FXMatrix* fields=new FXMatrix(this,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
     new FXLabel(fields,_("&File Name:"),NULL,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
     filename=new FXTextField(fields,25,this,ID_ACCEPT,TEXTFIELD_ENTER_ONLY|LAYOUT_FILL_COLUMN|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
     new FXButton(fields,_("&OK"),NULL,this,ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
-    accept=new FXButton(buttons,NULL,NULL,NULL,0,LAYOUT_FIX_X|LAYOUT_FIX_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,0,0, 0,0,0,0);
+    accept=new FXButton(buttons,FXString::null,NULL,NULL,0,LAYOUT_FIX_X|LAYOUT_FIX_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,0,0, 0,0,0,0);
     new FXLabel(fields,_("File F&ilter:"),NULL,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
-    FXHorizontalFrame *filterframe=new FXHorizontalFrame(fields,LAYOUT_FILL_COLUMN|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
+    FXHorizontalFrame* filterframe=new FXHorizontalFrame(fields,LAYOUT_FILL_COLUMN|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
 
   	filefilter=new FXComboBox(filterframe,10,this,ID_FILEFILTER,COMBOBOX_STATIC|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
   	filefilter->setNumVisible(4);
 	
     readonly=new FXCheckButton(filterframe,_("Read Only"),NULL,0,ICON_BEFORE_TEXT|JUSTIFY_LEFT|LAYOUT_CENTER_Y);
     cancel=new FXButton(fields,_("&Cancel"),NULL,NULL,0,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
-    FXHorizontalFrame *frame=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0,0,0,0,0);
+    FXHorizontalFrame* frame=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0,0,0,0,0);
     filebox=new FileList(frame,this,ID_FILELIST,ICONLIST_MINI_ICONS|ICONLIST_BROWSESELECT|ICONLIST_AUTOSIZE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     new FXLabel(buttons,_("Folder:"),NULL,LAYOUT_CENTER_Y);
-    updiricon=new FXPNGIcon(getApp(),dirup);
-    listicon=new FXPNGIcon(getApp(),smallicons);
-    iconsicon=new FXPNGIcon(getApp(),bigicons);
-    detailicon=new FXPNGIcon(getApp(),details);
-    homeicon=new FXPNGIcon(getApp(),home);
-    workicon=new FXPNGIcon(getApp(),work);
-    shownicon=new FXPNGIcon(getApp(),hidehidden);
-    hiddenicon=new FXPNGIcon(getApp(),showhidden);
-	showthumbicon=new FXPNGIcon(getApp(),showthumb);
-	hidethumbicon=new FXPNGIcon(getApp(),hidethumb);
-    dirbox=new DirBox(buttons,this,ID_DIRTREE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FIX_WIDTH|LAYOUT_CENTER_Y,0,0,160,0);
+    dirbox=new DirBox(buttons,this,ID_DIR_TREE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FIX_WIDTH|LAYOUT_CENTER_Y,0,0,160,0);
 	dirbox->setNumVisible(5);
     new FXFrame(buttons,LAYOUT_FIX_WIDTH,0,0,4,1);
-    new FXButton(buttons,_("\tGo up one folder\tMove up to higher folder."),updiricon,this,ID_DIRECTORY_UP,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    new FXButton(buttons,_("\tGo back\tMove to previous folder."),dirbackicon,this,ID_DIR_BACK,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+	btnbackhist=new FXArrowButton(buttons,this,ID_DIR_BACK_HIST,LAYOUT_FILL_Y|FRAME_RAISED|FRAME_THICK|ARROW_DOWN|ARROW_TOOLBAR);
+    new FXButton(buttons,_("\tGo forward\tMove to next folder."),dirforwardicon,this,ID_DIR_FORWARD,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+	btnforwardhist=new FXArrowButton(buttons,this,ID_DIR_FORWARD_HIST,LAYOUT_FILL_Y|FRAME_RAISED|FRAME_THICK|ARROW_DOWN|ARROW_TOOLBAR);
+    new FXButton(buttons,_("\tGo up one folder\tMove up to higher folder."),dirupicon,this,ID_DIR_UP,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tGo to home folder\tBack to home folder."),homeicon,this,ID_HOME,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tGo to working folder\tBack to working folder."),workicon,this,ID_WORK,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-    new FXButton(buttons,_("\tShow list\tDisplay folder with small icons."),listicon,filebox,FileList::ID_SHOW_MINI_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-    new FXButton(buttons,_("\tShow icons\tDisplay folder with big icons."),iconsicon,filebox,FileList::ID_SHOW_BIG_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-    new FXButton(buttons,_("\tShow details\tDisplay detailed folder listing."),detailicon,filebox,FileList::ID_SHOW_DETAILS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-    new FXToggleButton(buttons,_("\tShow hidden files\tShow hidden files and folders."),_("\tHide hidden Files\tHide hidden files and folders."),hiddenicon,shownicon,filebox,FileList::ID_TOGGLE_HIDDEN,TOGGLEBUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    new FXButton(buttons,_("\tShow list\tDisplay folder with small icons."),smalliconsicon,filebox,FileList::ID_SHOW_MINI_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    new FXButton(buttons,_("\tShow icons\tDisplay folder with big icons."),bigiconsicon,filebox,FileList::ID_SHOW_BIG_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    new FXButton(buttons,_("\tShow details\tDisplay detailed folder listing."),detailsicon,filebox,FileList::ID_SHOW_DETAILS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    new FXToggleButton(buttons,_("\tShow hidden files\tShow hidden files and folders."),_("\tHide hidden Files\tHide hidden files and folders."),hidehiddenicon,showhiddenicon,filebox,FileList::ID_TOGGLE_HIDDEN,TOGGLEBUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXToggleButton(buttons,_("\tShow thumbnails"),_("\tHide thumbnails"),showthumbicon,hidethumbicon,filebox,FileList::ID_TOGGLE_THUMBNAILS,TOGGLEBUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     readonly->hide();
   	if(table)
 	{
-    	table->addAccel(MKUINT(KEY_BackSpace,0),this,FXSEL(SEL_COMMAND,ID_DIRECTORY_UP));
+    	table->addAccel(MKUINT(KEY_BackSpace,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_DIR_BACK));
+    	table->addAccel(MKUINT(KEY_BackSpace,SHIFTMASK),this,FXSEL(SEL_COMMAND,ID_DIR_FORWARD));
+    	table->addAccel(MKUINT(KEY_BackSpace,0),this,FXSEL(SEL_COMMAND,ID_DIR_UP));
     	table->addAccel(MKUINT(KEY_h,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_HOME));
     	table->addAccel(MKUINT(KEY_w,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_WORK));
     	table->addAccel(MKUINT(KEY_a,CONTROLMASK),filebox,FXSEL(SEL_COMMAND,FileList::ID_SELECT_ALL));
@@ -94,7 +99,7 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
     }
     setSelectMode(SELECTFILE_ANY);    // For backward compatibility, this HAS to be the default!
     setPatternList(allfiles);
-    setDirectory(FXFile::getCurrentDirectory());
+    setDirectory(FXSystem::getCurrentDirectory());
     filebox->setFocus();
     accept->hide();
 }
@@ -247,7 +252,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
         }
 
         // Get directory part of path
-        FXString dir=FXFile::directory(path);
+        FXString dir=FXPath::directory(path);
 
         // In file mode, directory part of path should exist
         if(::isDirectory(dir))
@@ -302,8 +307,8 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
         }
 
         // Go up to the lowest directory which still exists
-        while(!FXFile::isTopDirectory(dir) && !::isDirectory(dir))
-            dir=FXFile::upLevel(dir);
+        while(!FXPath::isTopDirectory(dir) && !::isDirectory(dir))
+            dir=FXPath::upLevel(dir);
 
         // Switch as far as we could go
         dirbox->setDirectory(dir);
@@ -311,33 +316,31 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
 
         // Put the tail end back for further editing
         if(ISPATHSEP(path[dir.length()]))
-            path.remove(0,dir.length()+1);
+            path.erase(0,dir.length()+1);
         else
-            path.remove(0,dir.length());
+            path.erase(0,dir.length());
 
         // Replace text box with new stuff
         filename->setText(path);
         filename->selectAll();
     }
 
-    // Beep
-    getApp()->beep();
     return 1;
 }
 
 
 // User clicked up directory button
-long FileSelector::onCmdDirectoryUp(FXObject*,FXSelector,void*)
+long FileSelector::onCmdDirUp(FXObject*,FXSelector,void*)
 {
-    setDirectory(FXFile::upLevel(filebox->getDirectory()));
+    setDirectory(FXPath::upLevel(filebox->getDirectory()));
     return 1;
 }
 
 
 // Can we still go up
-long FileSelector::onUpdDirectoryUp(FXObject* sender,FXSelector,void*)
+long FileSelector::onUpdDirUp(FXObject* sender,FXSelector,void*)
 {
-    if(FXFile::isTopDirectory(filebox->getDirectory()))
+    if(FXPath::isTopDirectory(filebox->getDirectory()))
         sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
     else
         sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
@@ -345,10 +348,286 @@ long FileSelector::onUpdDirectoryUp(FXObject* sender,FXSelector,void*)
 }
 
 
+// Directory back
+long  FileSelector::onCmdDirBack(FXObject*,FXSelector s,void* p)
+{
+	StringList *backhist, *forwardhist;
+	StringItem *item;
+	FXString pathname;
+
+	// Get the filelist history
+	backhist=filebox->backhist;
+	forwardhist=filebox->forwardhist;
+
+	// Get the previous directory
+	item=backhist->getFirst();
+	if (item)
+		pathname=backhist->getString(item);
+	
+	// Update the history
+	backhist->removeFirstItem();
+	forwardhist->insertFirstItem(filebox->getDirectory());
+	
+	// Go to to the previous directory
+	filebox->setDirectory(pathname,FALSE);
+	dirbox->setDirectory(pathname);
+
+    return 1;
+}
+
+
+// Update directory back
+long  FileSelector::onUpdDirBack(FXObject* sender, FXSelector sel, void* ptr)
+{
+	StringList *backhist;
+	StringItem *item;
+	FXString pathname;
+
+	// Get the filelist history
+	backhist=filebox->backhist;
+	
+	// Gray out the button if no item in history 
+	FXint num=backhist->getNumItems();
+		
+	if (backhist->getNumItems()==0)
+		sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),ptr);	
+	else
+		sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),ptr);
+
+    return 1;
+}
+
+
+// Directory forward
+long  FileSelector::onCmdDirForward(FXObject*,FXSelector s,void* p)
+{
+	StringList *backhist, *forwardhist;
+	StringItem *item;
+	FXString pathname;
+
+	// Get the filelist history
+	backhist=filebox->backhist;
+	forwardhist=filebox->forwardhist;
+
+	// Get the next directory
+	item=forwardhist->getFirst();
+	if (item)
+		pathname=forwardhist->getString(item);
+	
+	// Update the history
+	forwardhist->removeFirstItem();
+	backhist->insertFirstItem(filebox->getDirectory());
+	
+	// Go to to the previous directory
+	filebox->setDirectory(pathname,FALSE);
+	dirbox->setDirectory(pathname);
+
+    return 1;
+}
+
+
+// Update directory forward
+long  FileSelector::onUpdDirForward(FXObject* sender, FXSelector sel, void* ptr)
+{
+	StringList *forwardhist;
+	StringItem *item;
+	FXString pathname;
+
+	// Get the filelist history
+	forwardhist=filebox->forwardhist;
+	
+	// Gray out the button if no item in history 
+	FXint num=forwardhist->getNumItems();
+	if (forwardhist->getNumItems()==0)
+		sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),ptr);	
+	else
+		sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),ptr);
+
+    return 1;
+}
+
+
+// Directory back history
+long  FileSelector::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
+{
+	StringList *backhist, *forwardhist;
+	StringItem *item;
+	FXString pathname;
+
+	// Get the filelist history
+	backhist=filebox->backhist;
+	forwardhist=filebox->forwardhist;
+
+	// Get all string items and display them in a list box
+	FXint num=backhist->getNumItems();
+	if (num>0)
+	{
+		FXString *dirs= new FXString[num];
+		FXString strlist="";
+		
+		// Get string items
+		item=backhist->getFirst();
+		for(int i=0; i<=num-1; i++)
+		{
+			if (item)
+			{
+				FXString str=backhist->getString(item);
+				dirs[i]=str;
+				strlist=strlist+str+"\n";
+				item=backhist->getNext(item);
+			}
+		}
+
+		// Display list box
+		FXWindow* owner=this->getOwner();
+		FXint pos=DirHistBox::box(btnbackhist,DECOR_NONE,strlist,owner->getX()+245,owner->getY()+37);
+		
+		// If an item was selected
+		if (pos!=-1)
+		{
+		
+			// Update back history
+			if (pos==num-1)
+				backhist->removeAllItems();
+			else
+			{
+				item=backhist->getItemAtPos(pos+1);
+				backhist->removeAllItemsBefore(item);
+			}
+			
+			// Update forward history
+			forwardhist->insertFirstItem(filebox->getDirectory());
+			if (pos>0)
+			{
+				for (FXint i=0; i<=pos-1; i++)
+					forwardhist->insertFirstItem(dirs[i]);
+			}
+	
+			// Go to to the selected directory
+			pathname=dirs[pos];
+			filebox->setDirectory(pathname,FALSE);
+			dirbox->setDirectory(pathname);
+		}
+		delete[]dirs;
+	}
+
+    return 1;
+}
+
+
+// Update directory back
+long  FileSelector::onUpdDirBackHist(FXObject* sender, FXSelector sel, void* ptr)
+{
+	StringList *backhist;
+	StringItem *item;
+	FXString pathname;
+
+	// Get the filelist history
+	backhist=filebox->backhist;
+	
+	// Gray out the button if no item in history 
+	FXint num=backhist->getNumItems();
+	if (backhist->getNumItems()==0)
+		sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),ptr);	
+	else
+		sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),ptr);
+
+    return 1;
+}
+
+
+// Directory forward history
+long  FileSelector::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* ptr)
+{
+	StringList *backhist, *forwardhist;
+	StringItem *item;
+	FXString pathname;
+
+	// Get the filelist history
+	backhist=filebox->backhist;
+	forwardhist=filebox->forwardhist;
+
+	// Get all string items and display them in a list box
+	FXint num=forwardhist->getNumItems();
+	if (num>0)
+	{
+		FXString *dirs= new FXString[num];
+		FXString strlist="";
+		
+		// Get string items
+		item=forwardhist->getFirst();
+		for(int i=0; i<=num-1; i++)
+		{
+			if (item)
+			{
+				FXString str=forwardhist->getString(item);
+				dirs[i]=str;
+				strlist=strlist+str+"\n";
+				item=forwardhist->getNext(item);
+			}
+		}
+		
+		// Display list box
+		FXWindow* owner=this->getOwner();
+		FXint pos=DirHistBox::box(btnforwardhist,DECOR_NONE,strlist,owner->getX()+285,owner->getY()+37);
+		
+		// If an item was selected
+		if (pos!=-1)
+		{
+			// Update forward history
+			if (pos==num-1)
+				forwardhist->removeAllItems();
+			else
+			{
+				item=forwardhist->getItemAtPos(pos+1);
+				forwardhist->removeAllItemsBefore(item);
+			}
+			
+			// Update back history
+			backhist->insertFirstItem(filebox->getDirectory());
+			if (pos>0)
+			{
+				for (FXint i=0; i<=pos-1; i++)
+					backhist->insertFirstItem(dirs[i]);
+			}
+	
+			// Go to to the selected directory
+			pathname=dirs[pos];
+			filebox->setDirectory(pathname,FALSE);
+			dirbox->setDirectory(pathname);
+		}
+		delete[]dirs;
+	}
+
+    return 1;
+}
+
+
+// Update directory forward
+long  FileSelector::onUpdDirForwardHist(FXObject* sender, FXSelector sel, void* ptr)
+{
+	StringList *forwardhist;
+	StringItem *item;
+	FXString pathname;
+
+	// Get the filelist history
+	forwardhist=filebox->forwardhist;
+	
+	// Gray out the button if no item in history 
+	FXint num=forwardhist->getNumItems();
+	if (forwardhist->getNumItems()==0)
+		sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),ptr);
+	else
+		sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),ptr);
+
+    return 1;
+}
+
+
 // Back to home directory
 long FileSelector::onCmdHome(FXObject*,FXSelector,void*)
 {
-    setDirectory(FXFile::getHomeDirectory());
+    setDirectory(FXSystem::getHomeDirectory());
     return 1;
 }
 
@@ -356,7 +635,7 @@ long FileSelector::onCmdHome(FXObject*,FXSelector,void*)
 // Back to current working directory
 long FileSelector::onCmdWork(FXObject*,FXSelector,void*)
 {
-    setDirectory(FXFile::getCurrentDirectory());
+    setDirectory(FXSystem::getCurrentDirectory());
     return 1;
 }
 
@@ -422,7 +701,7 @@ long FileSelector::onCmdFilter(FXObject*,FXSelector,void* ptr)
         FXString ext=extensionFromPattern(pat);
         if(!ext.empty())
         {
-            FXString name=FXFile::stripExtension(filename->getText());
+            FXString name=FXPath::stripExtension(filename->getText());
             if(!name.empty())
                 filename->setText(name+"."+ext);
         }
@@ -434,7 +713,7 @@ long FileSelector::onCmdFilter(FXObject*,FXSelector,void* ptr)
 // Set directory
 void FileSelector::setDirectory(const FXString& path)
 {
-    FXString abspath=FXFile::absolute(path);
+    FXString abspath=FXPath::absolute(path);
     filebox->setDirectory(abspath);
     dirbox->setDirectory(abspath);
     if(selectmode!=SELECTFILE_ANY)
@@ -452,10 +731,10 @@ FXString FileSelector::getDirectory() const
 // Set file name
 void FileSelector::setFilename(const FXString& path)
 {
-    FXString abspath=FXFile::absolute(path);
+    FXString abspath=FXPath::absolute(path);
     filebox->setCurrentFile(abspath);
-    dirbox->setDirectory(FXFile::directory(abspath));
-    filename->setText(FXFile::name(abspath));
+    dirbox->setDirectory(FXPath::directory(abspath));
+    filename->setText(FXPath::name(abspath));
 }
 
 
@@ -468,7 +747,7 @@ FXString FileSelector::getFilename() const
         for(i=0; i<filebox->getNumItems(); i++)
         {
             if(filebox->isItemSelected(i) && filebox->getItemFilename(i)!="..")
-                return FXFile::absolute(filebox->getDirectory(),filebox->getItemFilename(i));
+                return FXPath::absolute(filebox->getDirectory(),filebox->getItemFilename(i));
         }
     }
     else if(selectmode==SELECTFILE_MULTIPLE)
@@ -476,13 +755,13 @@ FXString FileSelector::getFilename() const
         for(i=0; i<filebox->getNumItems(); i++)
         {
             if(filebox->isItemSelected(i) && filebox->isItemFile(i))
-                return FXFile::absolute(filebox->getDirectory(),filebox->getItemFilename(i));
+                return FXPath::absolute(filebox->getDirectory(),filebox->getItemFilename(i));
         }
     }
     else
     {
         if(!filename->getText().empty())
-            return FXFile::absolute(filebox->getDirectory(),filename->getText());
+            return FXPath::absolute(filebox->getDirectory(),filename->getText());
     }
     return FXString::null;
 }
@@ -719,52 +998,6 @@ FXbool FileSelector::getReadOnly() const
 }
 
 
-// Save data
-void FileSelector::save(FXStream& store) const
-{
-    FXPacker::save(store);
-    store << filebox;
-    store << filename;
-    store << filefilter;
-    store << readonly;
-    store << dirbox;
-    store << accept;
-    store << cancel;
-    store << updiricon;
-    store << listicon;
-    store << detailicon;
-    store << iconsicon;
-    store << homeicon;
-    store << workicon;
-    store << shownicon;
-    store << hiddenicon;
-    store << selectmode;
-}
-
-
-// Load data
-void FileSelector::load(FXStream& store)
-{
-    FXPacker::load(store);
-    store >> filebox;
-    store >> filename;
-    store >> filefilter;
-    store >> readonly;
-    store >> dirbox;
-    store >> accept;
-    store >> cancel;
-    store >> updiricon;
-    store >> listicon;
-    store >> detailicon;
-    store >> iconsicon;
-    store >> homeicon;
-    store >> workicon;
-    store >> shownicon;
-    store >> hiddenicon;
-    store >> selectmode;
-}
-
-
 // Cleanup; icons must be explicitly deleted
 FileSelector::~FileSelector()
 {
@@ -777,29 +1010,15 @@ FileSelector::~FileSelector()
     	table->removeAccel(MKUINT(KEY_a,CONTROLMASK));
     	table->removeAccel(MKUINT(KEY_i,CONTROLMASK));
     }
-    delete updiricon;
-    delete listicon;
-    delete detailicon;
-    delete iconsicon;
-    delete homeicon;
-    delete workicon;
-    delete shownicon;
-    delete hiddenicon;
-    filebox=(FileList*)-1;
-    filename=(FXTextField*)-1;
-    filefilter=(FXComboBox*)-1;
-    readonly=(FXCheckButton*)-1;
-    dirbox=(DirBox*)-1;
-    accept=(FXButton*)-1;
-    cancel=(FXButton*)-1;
-    updiricon=(FXIcon*)-1;
-    listicon=(FXIcon*)-1;
-    detailicon=(FXIcon*)-1;
-    iconsicon=(FXIcon*)-1;
-    homeicon=(FXIcon*)-1;
-    workicon=(FXIcon*)-1;
-    shownicon=(FXIcon*)-1;
-    hiddenicon=(FXIcon*)-1;
+    delete filebox;
+	delete filename;
+	delete filefilter;
+	delete readonly;
+	delete dirbox;
+	delete accept;
+	delete cancel;
+	delete btnbackhist;
+	delete btnforwardhist;
 }
 
 
@@ -987,26 +1206,10 @@ FXbool FileDialog::getReadOnly() const
 }
 
 
-// Save data
-void FileDialog::save(FXStream& store) const
-{
-    FXDialogBox::save(store);
-    store << filebox;
-}
-
-
-// Load data
-void FileDialog::load(FXStream& store)
-{
-    FXDialogBox::load(store);
-    store >> filebox;
-}
-
-
 // Cleanup
 FileDialog::~FileDialog()
 {
-    filebox=(FileSelector*)-1;
+    delete filebox;
 }
 
 
