@@ -3,8 +3,8 @@
 #include "config.h"
 #include "i18n.h"
 
-#include <fox-1.4/fx.h>
-#include <fox-1.4/FXPNGIcon.h>
+#include <fox-1.6/fx.h>
+#include <fox-1.6/FXPNGIcon.h>
 
 #include "xfedefs.h"
 #include "icons.h"
@@ -16,22 +16,11 @@
 #define MIMETYPELEN  64
 #define ICONNAMELEN  256
 
-// You can override the default icon locations to search for your
-// particular platform by specifying -DDEFAULTICONPATH="path" on
-// the command line.
-#ifndef DEFAULTICONPATH
-#define DEFAULTICONPATH   "~/.foxicons:/usr/local/share/icons:/usr/share/icons"
-#endif
-
 
 // Object implementation
 FXIMPLEMENT(IconDict,FXDict,NULL,0)
 
 
-// Default icon path
-const FXchar IconDict::defaultIconPath[]=DEFAULTICONPATH;
-
-
 // Build icon table
 IconDict::IconDict(FXApp* a,const FXString& p):app(a),path(p)
 {
@@ -68,8 +57,10 @@ void *IconDict::createData(const void* ptr)
         // Got icon
         if(icon)
         {
+
             // Find icon in the icon directory
-            FXString iconfile=FXFile::search(path,(const char*)ptr);
+            FXString iconfile=FXPath::search(path,(const char*)ptr);
+
             if(!iconfile.empty())
             {
                 FXFileStream str;
@@ -80,7 +71,10 @@ void *IconDict::createData(const void* ptr)
                     // Load it
                     icon->loadPixels(str);
 
-                    // Done
+                    // Create it
+					icon->create();
+					
+					// Done
                     str.close();
 
                     return icon;
@@ -102,24 +96,6 @@ void IconDict::deleteData(void* ptr)
 }
 
 
-// Save data
-void IconDict::save(FXStream& store) const
-{
-    FXDict::save(store);
-    store << app;
-    store << path;
-}
-
-
-// Load data
-void IconDict::load(FXStream& store)
-{
-    FXDict::load(store);
-    store >> app;
-    store >> path;
-}
-
-
 // Destructor
 IconDict::~IconDict()
 {
@@ -141,14 +117,14 @@ FXIMPLEMENT(FileDict,FXDict,NULL,0)
 // Construct an file-extension association table
 FileDict::FileDict(FXApp* a):app(a),settings(&a->reg())
 {
-    icons=new IconDict(a,settings->readStringEntry("SETTINGS","iconpath",IconDict::defaultIconPath));
+    icons=new IconDict(a,settings->readStringEntry("SETTINGS","iconpath",DEFAULTICONPATH));
 }
 
 
 // Construct an file-extension association table, and alternative settings database
 FileDict::FileDict(FXApp* a,FXSettings* db):app(a),settings(db)
 {
-    icons=new IconDict(a,settings->readStringEntry("SETTINGS","iconpath",IconDict::defaultIconPath));
+    icons=new IconDict(a,settings->readStringEntry("SETTINGS","iconpath",DEFAULTICONPATH));
 }
 
 
@@ -347,19 +323,19 @@ FileAssoc* FileDict::findFileBinding(const FXchar* pathname)
     register const FXchar *filename=pathname;
     register const FXchar *p=pathname;
     register FileAssoc* record;
+	
     while(*p)
     {
         if(ISPATHSEP(*p))
             filename=p+1;
         p++;
     }
-    
 	record=associate(filename);
     if(record)
         return record;
 
     filename=strchr(filename,'.');
-
+	
     while(filename)
     {
 		if (strlen(filename)>1)
@@ -397,24 +373,6 @@ FileAssoc* FileDict::findExecBinding(const FXchar* pathname)
 }
 
 
-// Save data
-void FileDict::save(FXStream& store) const
-{
-    FXDict::save(store);
-    store << app;
-    store << icons;
-}
-
-
-// Load data
-void FileDict::load(FXStream& store)
-{
-    FXDict::load(store);
-    store >> app;
-    store >> icons;
-}
-
-
 // Destructor
 FileDict::~FileDict()
 {
