@@ -1,6 +1,8 @@
 #ifndef FILELIST_H
 #define FILELIST_H
 
+#include "StringList.h"
+
 
 struct FileAssoc;
 class  FileDict;
@@ -16,6 +18,7 @@ protected:
 	FileItem   *link;                   	// Link to next item
     unsigned long long size;                // File size
     FXTime        date;                     // File time
+	FXTime		  deldate;
 protected:
     FileItem():assoc(NULL),link(NULL),size(0),date(0)
     {}
@@ -122,44 +125,16 @@ protected:
 	FXbool		ignorecase;				// Case sensitivity for file name sorting
 	FXbool		allowrefresh;			// Allow or disallow periodic refresh
 	FXbool		displaythumbnails;		// Display thumbnails
-    FXIcon      *big_folder;            
-    FXIcon      *mini_folder;           
-    FXIcon      *big_doc;               
-    FXIcon      *mini_doc;              
-    FXIcon      *big_exec;              
-    FXIcon      *mini_exec;             
-	FXIcon  	*mini_folderopen;
-	FXIcon  	*mini_folderup;
-	FXIcon  	*mini_lockfolder;
-	FXIcon  	*mini_cdev;
-	FXIcon  	*mini_bdev;
-	FXIcon  	*mini_sock;
-	FXIcon  	*mini_pipe;
-	FXIcon  	*mini_link;
-	FXIcon  	*mini_brokenlink;
-	FXIcon  	*big_folderopen;
-	FXIcon  	*big_folderup;
-	FXIcon  	*big_lockfolder;
-	FXIcon  	*big_cdev;
-	FXIcon  	*big_bdev;
-	FXIcon  	*big_sock;
-	FXIcon  	*big_pipe;
-	FXIcon  	*big_harddisk;
-	FXIcon  	*mini_harddisk;
-	FXIcon  	*big_link;
-	FXIcon  	*big_brokenlink;
-    FXIcon  	*big_nfs;
-    FXIcon  	*mini_nfs;
-    FXIcon  	*big_floppy;
-    FXIcon  	*mini_floppy;
-    FXIcon  	*big_cdrom;
-    FXIcon  	*mini_cdrom;
-    FXIcon  	*big_zip;
-    FXIcon  	*mini_zip;
 	FXColor 	*tmpdata;				// Temporary image data
+	FXString	trashlocation;
+
+public:
+	StringList		*backhist;          // Back history
+	StringList		*forwardhist;       // Forward history
 
 protected:
-    FileList();
+    FileList()
+	{}
     virtual FXIconItem *createItem(const FXString& text,FXIcon *big,FXIcon* mini,void* ptr);
     void listItems();
 private:
@@ -177,9 +152,6 @@ public:
     long onBeginDrag(FXObject*,FXSelector,void*);
     long onEndDrag(FXObject*,FXSelector,void*);
     long onDragged(FXObject*,FXSelector,void*);
-    long onCmdSetValue(FXObject*,FXSelector,void*);
-    long onCmdGetStringValue(FXObject*,FXSelector,void*);
-    long onCmdSetStringValue(FXObject*,FXSelector,void*);
     long onCmdDirectoryUp(FXObject*,FXSelector,void*);
     long onUpdDirectoryUp(FXObject*,FXSelector,void*);
 	long onCmdSortByName(FXObject*,FXSelector,void*);
@@ -188,20 +160,24 @@ public:
 	long onUpdSortByType(FXObject*,FXSelector,void*);
 	long onCmdSortBySize(FXObject*,FXSelector,void*);
 	long onUpdSortBySize(FXObject*,FXSelector,void*);
+	long onCmdSortByExt(FXObject*,FXSelector,void*);
+	long onUpdSortByExt(FXObject*,FXSelector,void*);
 	long onCmdSortByTime(FXObject*,FXSelector,void*);
 	long onUpdSortByTime(FXObject*,FXSelector,void*);
 	long onCmdSortByUser(FXObject*,FXSelector,void*);
 	long onUpdSortByUser(FXObject*,FXSelector,void*);
 	long onCmdSortByGroup(FXObject*,FXSelector,void*);
 	long onUpdSortByGroup(FXObject*,FXSelector,void*);
+	long onCmdSortByPerm(FXObject*,FXSelector,void*);
+	long onUpdSortByPerm(FXObject*,FXSelector,void*);
+	long onCmdSortByDeltime(FXObject*,FXSelector,void*);
+	long onUpdSortByDeltime(FXObject*,FXSelector,void*);
 	long onCmdSortReverse(FXObject*,FXSelector,void*);
 	long onUpdSortReverse(FXObject*,FXSelector,void*);
 	long onCmdSortCase(FXObject*,FXSelector,void*);
 	long onUpdSortCase(FXObject*,FXSelector,void*);
     long onCmdSetPattern(FXObject*,FXSelector,void*);
     long onUpdSetPattern(FXObject*,FXSelector,void*);
-    long onCmdSetDirectory(FXObject*,FXSelector,void*);
-    long onUpdSetDirectory(FXObject*,FXSelector,void*);
     long onCmdToggleHidden(FXObject*,FXSelector,void*);
     long onUpdToggleHidden(FXObject*,FXSelector,void*);
     long onCmdShowHidden(FXObject*,FXSelector,void*);
@@ -221,20 +197,30 @@ public:
 	static FXint descendingType(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint ascendingSize(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint descendingSize(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingExt(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingExt(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint ascendingTime(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint descendingTime(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint ascendingUser(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint descendingUser(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint ascendingGroup(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint descendingGroup(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingPerm(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingPerm(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingDeltime(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingDeltime(const FXIconItem* pa,const FXIconItem* pb);
 public:
-    enum {
+	enum {
+		// Note : the order of the 9 following sort IDs must be kept
         ID_SORT_BY_NAME=FXIconList::ID_LAST,
         ID_SORT_BY_SIZE,
         ID_SORT_BY_TYPE,
+        ID_SORT_BY_EXT,
         ID_SORT_BY_TIME,
         ID_SORT_BY_USER,
         ID_SORT_BY_GROUP,
+        ID_SORT_BY_PERM,   
+        ID_SORT_BY_DELTIME,
         ID_SORT_REVERSE,
     	ID_SORT_CASE,
         ID_DIRECTORY_UP,
@@ -267,7 +253,7 @@ public:
     FXString getCurrentFile() const;
 
     // Set current directory
-    void setDirectory(const FXString& path);
+    void setDirectory(const FXString& path, const FXbool histupdate=TRUE);
 
     // Return current directory
     FXString getDirectory() const
