@@ -2,6 +2,7 @@
 #define FILEPANEL_H
 #include "Properties.h"
 #include "FileList.h"
+#include "PathLinker.h"
 
 // Clipboard operations
 enum
@@ -15,11 +16,13 @@ class FilePanel : public FXVerticalFrame
     FXDECLARE(FilePanel)
     friend class XFileExplorer;
     friend class DirPanel;
+    friend class PathLinker;
+	friend class PropertiesBox;
 protected:
     FilePanel*		current;
     FileList*	  	list;
     FilePanel*		next;
-    FXLabel*		label;
+    PathLinker*		pathlink;
 	FXPacker* 		statusbar;
     FXLabel*		status;
     FXString 		name;
@@ -27,32 +30,11 @@ protected:
 	FXbool			selmult;
 	FXString		homelocation;
 	FXString		trashlocation;
-
-    FXIcon			*archicon;
-    FXIcon			*attricon;
-	FXIcon			*newfoldericon;
-	FXIcon			*minidocicon;
-	FXIcon			*delicon;	
-	FXIcon			*copyicon;	
-	FXIcon			*cuticon;	
-	FXIcon			*pasteicon;
-	FXIcon			*symlinkicon;
-	FXIcon			*renameicon;
-	FXIcon			*moveicon;
-	FXIcon			*mapicon;	
-	FXIcon			*unmapicon;	
-	FXIcon			*minixtermicon;
-	FXIcon			*minirpmicon;
-	FXIcon			*locationicon;
-	FXIcon			*entericon;
-	FXIcon			*filtericon;
-	FXIcon			*viewicon;
-	FXIcon			*editicon;
-	FXIcon			*openicon;
+	FXDragCorner    *corner;
 
 
 public:
-    FilePanel(FXchar*,FXComposite*, FXuint name_size=200, FXuint size_size=60, FXuint type_size=100, 
+    FilePanel(FXchar*,FXComposite*, FXuint name_size=200, FXuint size_size=60, FXuint type_size=100, FXuint ext_size=100, 
 	      FXuint modd_size=150, FXuint user_size=50, FXuint grou_size=50, FXuint attr_size=100, FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0),
  		  FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
     FilePanel()
@@ -63,6 +45,7 @@ public:
     void unfocus();
     void Next(FilePanel*);
 	void updateLocation();
+	void showCorner(FXbool show);
     enum {
         ID_FILE_PANEL=FXVerticalFrame::ID_LAST,
         ID_DIRECTORY_UP,
@@ -74,7 +57,8 @@ public:
         ID_FILE_MOVE,
         ID_FILE_RENAME,
         ID_FILE_SYMLINK,
-        ID_FILE_DEL,
+        ID_FILE_DELETE,
+        ID_FILE_TRASH,
         ID_FILE_ASSOC,
 		ID_MENU,
 		ID_XTERM,
@@ -84,6 +68,7 @@ public:
         ID_NEW_FILE,
         ID_ADD_TO_ARCH,
         ID_GO_HOME,
+		ID_GO_TRASH,
         ID_COPY_CLP,
         ID_CUT_CLP,
         ID_PASTE_CLP,
@@ -104,16 +89,14 @@ public:
 #if defined(linux)
         ID_MOUNT,
         ID_UMOUNT,
-		ID_RPM_QUERY,
-		ID_RPM_INSTALL,
-		ID_RPM_UNINSTALL,
+		ID_PKG_QUERY,
+		ID_PKG_INSTALL,
+		ID_PKG_UNINSTALL,
 #endif
         ID_LAST,
     };
 public:
     long onUpdStatus(FXObject*,FXSelector,void*);
-    long onUpdLabel(FXObject*,FXSelector,void*);
-    long onLabelClcked(FXObject*,FXSelector,void*);
     long onCmdItemDblClcked(FXObject*,FXSelector,void*);
     long onCmdItemFilter(FXObject*,FXSelector,void*);
     long onCmdClp(FXObject*,FXSelector,void*);
@@ -121,10 +104,12 @@ public:
     long onCmdItemClcked(FXObject*,FXSelector,void*);
     long onCmdDirectoryUp(FXObject*,FXSelector,void*);
     long onCmdGoHome(FXObject*,FXSelector,void*);
+	long onCmdGoTrash(FXObject*,FXSelector,void*);
     long onCmdEdit(FXObject*,FXSelector,void*);
     long onCmdProperties(FXObject*,FXSelector,void*);
     long onCmdFileMan(FXObject*,FXSelector,void*);
-    long onCmdFileDel(FXObject*,FXSelector,void*);
+    long onCmdFileTrash(FXObject*,FXSelector,void*);
+	long onCmdFileDelete(FXObject*,FXSelector,void*);
     long onCmdFileAssoc(FXObject*,FXSelector,void*);
     long onCmdNewDir(FXObject*,FXSelector,void*);
     long onCmdNewFile(FXObject*,FXSelector,void*);
@@ -149,13 +134,19 @@ public:
 	long onUpdOpen(FXObject*,FXSelector,void*);
 	long onUpdAddToArch(FXObject*,FXSelector,void*);
 	long onUpdSelMult(FXObject*,FXSelector,void*);
+	long onUpdFileDelete(FXObject*,FXSelector,void*);
+	long onUpdFileTrash(FXObject*,FXSelector,void*);
+	long onUpdGoTrash(FXObject* o,FXSelector sel,void*);
+	void updatePathLinker();
+
 #if defined(linux)
     long onCmdMount(FXObject*,FXSelector,void*);
     long onUpdMount(FXObject*,FXSelector,void*);
     long onUpdUnmount(FXObject*,FXSelector,void*);
-    long onCmdRpmQuery(FXObject*,FXSelector,void*);
-    long onCmdRpmInstall(FXObject*,FXSelector,void*);
-    long onCmdRpmUninstall(FXObject*,FXSelector,void*);
+    long onCmdPkgQuery(FXObject*,FXSelector,void*);
+    long onUpdPkgQuery(FXObject*,FXSelector,void*);
+    long onCmdPkgInstall(FXObject*,FXSelector,void*);
+    long onCmdPkgUninstall(FXObject*,FXSelector,void*);
 #endif
 };
 #endif
