@@ -41,7 +41,7 @@ private:
         ;
     }
 public:
-    HistInputDialog(FXWindow*,FXString& ,FXString,FXString,FXString label="",FXIcon *ic=NULL, int option=0, FXString=NULL);
+    HistInputDialog(FXWindow*,FXString& ,FXString,FXString,FXString label="",FXIcon *ic=NULL, int option=0, FXString=FXString::null);
     virtual void create();
     long onCmdKeyPress(FXObject*,FXSelector,void*);
     FXString getText()
