@@ -22,6 +22,10 @@ public:
     {
         return input->getText();
     }
+	void setText(const FXString& text)
+	{
+		input->setText(text);
+	}
     void SelectAll()
     {
         input->setSelection(0,(input->getText()).length());
