@@ -3,20 +3,24 @@
 
 #include <string.h>
 
+
+// Number of modifiable colors
+#define COLORS_NUM 9
+
 // Number of themes
-#define THEMES_NUM 10
+#define THEMES_NUM 12
 
 
 struct Theme
 {
     char *name;
-    FXColor color[8];
+    FXColor color[9];
     Theme()
     {
         name = "";
     };
     Theme(const char *n,FXColor base=0,FXColor bdr=0,FXColor bg=0,FXColor fg=0,
-	                    FXColor selbg=0,FXColor selfg=0, FXColor listbg=0, FXColor listfg=0)
+	                    FXColor selbg=0,FXColor selfg=0, FXColor listbg=0, FXColor listfg=0, FXColor listhl=0)
     {
         name = strdup(n);
         color[0] = base;
@@ -27,7 +31,9 @@ struct Theme
         color[5] = selfg;
 		color[6] = listbg;
 		color[7] = listfg;
-    };
+ 		color[7] = listfg;
+  		color[8] = listhl;
+  };
     FXbool operator != (const Theme&);
 };
 
@@ -42,20 +48,23 @@ private:
     FXComboBox *themesBox;
     FXList     *themesList;
     FXTextField *iconpath;
-    FXTextField *editor;
-    FXTextField *viewer;
+    FXTextField *txteditor;
+    FXTextField *txtviewer;
+    FXTextField *imgviewer;
     FXTextField *xterm;
     FXTextField *normalfont;
     FXTextField *textfont;
     FXString    oldiconpath;
-    FXString    oldeditor;
-    FXString    oldviewer;
+    FXString    oldtxteditor;
+    FXString    oldtxtviewer;
+    FXString    oldimgviewer;
     FXString    oldxterm;
     FXString    oldnormalfont;
     FXString    oldtextfont;
     FXCheckButton  *autosave;
     FXCheckButton  *quit;
     FXCheckButton  *trashcan;
+    FXCheckButton  *trashbypass;
     FXCheckButton  *del;
     FXCheckButton  *overwrite;
     FXCheckButton  *ask;
@@ -68,19 +77,21 @@ private:
 public:
     enum{
         ID_ACCEPT=FXDialogBox::ID_LAST,
-        ID_BROWSE_EDIT,
-        ID_BROWSE_VIEW,
+        ID_BROWSE_TXTEDIT,
+        ID_BROWSE_TXTVIEW,
+		ID_BROWSE_IMGVIEW,
         ID_BROWSE_XTERM,
         ID_COLOR,
 		ID_NORMALFONT,
 		ID_TEXTFONT,
         ID_THEME,
         ID_BROWSE_ICON_PATH,
+		ID_TRASH_BYPASS,
         ID_LAST
     };
 
 public:
-    PreferencesBox(FXWindow *win,FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0));
+    PreferencesBox(FXWindow *win,FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXColor highlightcolor=FXRGB(238,2380,238));
     long onCmdAccept(FXObject*,FXSelector,void*);
     long onCmdBrowse(FXObject*,FXSelector,void*);
     long onCmdColor (FXObject*,FXSelector,void*);
@@ -89,5 +100,6 @@ public:
     long onCmdBrowsePath(FXObject*,FXSelector,void*);
 	long onCmdNormalFont(FXObject*,FXSelector,void*);
 	long onCmdTextFont(FXObject*,FXSelector,void*);
+	long onUpdTrashBypass(FXObject* o,FXSelector,void*);
 };
 #endif
