@@ -11,6 +11,7 @@
 #include <sys/stat.h>
 #include <dirent.h>
 
+#include "xfedefs.h"
 #include "FileDict.h"
 #include "FilePanel.h"
 #include "InputDialog.h"
@@ -28,6 +29,8 @@ class XFileExplorer : public FXMainWindow
     FXDECLARE(XFileExplorer)
     friend class FilePanel;
     friend class DirPanel;
+    friend class PathLinker;
+	friend class PropertiesBox;
 protected:
 	int rpanel_width;
 	int rpanel_tree_width;
@@ -40,14 +43,27 @@ protected:
 	};	
 	int panel_view;
     int RunHistSize;
-#define RUN_HIST_SIZE 15
     char RunHistory[RUN_HIST_SIZE][100];
-    FXMenuPane		*leftviewmenu;
-    FXMenuPane		*rightviewmenu;
-    FXMenuTitle		*rmenutitle;
-    FXMenuTitle		*lmenutitle;
-    Bookmarks		*bookmarks;
 	FXMenuBar		*menubar;
+    FXMenuPane		*toolsmenu;
+    FXMenuPane		*filemenu;
+    FXMenuPane		*trashmenu;
+    FXMenuPane		*editmenu;
+    FXMenuPane		*bookmarksmenu;
+    FXMenuPane		*viewmenu;
+	FXMenuPane		*lpanelmenu;
+    FXMenuPane		*rpanelmenu;
+    FXMenuPane		*helpmenu;
+    FXMenuTitle		*toolsmenutitle;
+    FXMenuTitle		*filemenutitle;
+    FXMenuTitle		*trashmenutitle;
+    FXMenuTitle		*editmenutitle;
+    FXMenuTitle		*bookmarksmenutitle;
+    FXMenuTitle		*viewmenutitle;
+	FXMenuTitle		*lpanelmenutitle;
+    FXMenuTitle		*rpanelmenutitle;
+    FXMenuTitle		*helpmenutitle;
+    Bookmarks		*bookmarks;
     FXToolBar		*toolbar;
     FXToolBar		*locationbar;
 	FXComboBox		*address;
@@ -67,6 +83,10 @@ protected:
 	FXuint			height;
 	FXColor			listbackcolor;
 	FXColor			listforecolor;
+    FXButton		*btndel;
+    FXButton		*btntrash;
+	FXArrowButton   *btnbackhist;
+	FXArrowButton   *btnforwardhist;
 public:
     enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
@@ -74,17 +94,23 @@ public:
 		ID_REFRESH,
 		ID_EMPTY_TRASHCAN,
         ID_XTERM,
+		ID_DIR_BACK,
+		ID_DIR_FORWARD,
+		ID_DIR_BACK_HIST,
+		ID_DIR_FORWARD_HIST,
         ID_FILE_COPY,
         ID_FILE_RENAME,
         ID_FILE_MOVE,
         ID_FILE_COPYTO,
         ID_FILE_CUT,
         ID_FILE_SYMLINK,
-        ID_FILE_DEL,
+        ID_FILE_DELETE,
+        ID_FILE_TRASH,
         ID_FILE_ASSOC,
 		ID_CLEAR_LOCATION,
 		ID_GOTO_LOCATION,
         ID_RUN,
+        ID_SU,
         ID_PREFS,
         ID_DIR_BOX,
         ID_TOGGLE_STATUS,
@@ -97,7 +123,11 @@ public:
         ID_BOOKMARK,
         ID_ADD_BOOKMARK,
         ID_QUIT,
-        ID_LAST
+		ID_OPTION1,
+ 		ID_OPTION2,
+ 		ID_OPTION3,
+		ID_OPTION4,
+      ID_LAST
     };
 public:
     XFileExplorer(FXApp *app=NULL,char *title = "X File Explorer",FXIcon *bigicon=NULL,FXIcon *miniicon=NULL);
@@ -118,6 +148,7 @@ public:
     long onCmdPopupMenu(FXObject*,FXSelector,void*);
     long onCmdPrefs(FXObject*,FXSelector,void*);
     long onCmdRun(FXObject*,FXSelector,void*);
+	long onCmdSu(FXObject*,FXSelector,void*);
     long onCmdXTerm(FXObject*,FXSelector,void*);
 	long onCmdEmptyTrashcan(FXObject*,FXSelector,void*);
     long onCmdFileMan(FXObject*,FXSelector,void*);
@@ -131,5 +162,17 @@ public:
 	long onUpdShowPanels(FXObject*,FXSelector,void*);
 	long onUpdFileLocation(FXObject*,FXSelector,void*);
 	long onUpdEmptyTrashcan(FXObject*,FXSelector,void*);
+	long onCmdFileDelete(FXObject*,FXSelector sel,void*);
+	long onCmdFileTrash(FXObject*,FXSelector sel,void*);
+	long onUpdFileDelete(FXObject*,FXSelector,void*);
+	long onUpdFileTrash(FXObject*,FXSelector,void*);
+	long onCmdDirBack(FXObject*,FXSelector,void*);
+	long onUpdDirBack(FXObject*,FXSelector,void*);
+	long onCmdDirForward(FXObject*,FXSelector,void*);
+	long onUpdDirForward(FXObject*,FXSelector,void*);
+	long onCmdDirBackHist(FXObject*,FXSelector,void*);
+	long onUpdDirBackHist(FXObject*,FXSelector,void*);
+	long onCmdDirForwardHist(FXObject*,FXSelector,void*);
+	long onUpdDirForwardHist(FXObject*,FXSelector,void*);
 };
 #endif
