@@ -11,23 +11,29 @@
 #include <unistd.h>
 #include <signal.h>
 
-#include <fox-1.4/fx.h>
-#include <fox-1.4/fxkeys.h>
-#include <fox-1.4/FXPNGImage.h>
-#include <fox-1.4/FXJPGImage.h>
-#include <fox-1.4/FXTIFImage.h>
-#include <fox-1.4/FXPNGIcon.h>
+#include <fox-1.6/fx.h>
+#include <fox-1.6/fxkeys.h>
+#include <fox-1.6/FXPNGImage.h>
+#include <fox-1.6/FXJPGImage.h>
+#include <fox-1.6/FXTIFImage.h>
+#include <fox-1.6/FXPNGIcon.h>
 
+#include "xfedefs.h"
 #include "icons.h"
 #include "FileList.h"
 #include "FileDialog.h"
+#include "InputDialog.h"
 #include "MessageBox.h"
 #include "XFileImage.h"
 
+// Add FOX hacks
+#include "foxhacks.cc"
 
 FXMainWindow *mainWindow;
 char **args;
 FXColor listbackcolor, listforecolor;
+FXColor highlightcolor;
+FXbool allowPopupScroll=FALSE;
 
 // Predefined zoom factors 
 #define NB_ZOOM 24
@@ -53,7 +59,9 @@ const FXchar *patterns[]=
     _("PPM Image"),		"*.ppm",
     _("PNG Image"),		"*.png",
     _("JPEG Image"),	"*.jpg",
+    _("JPEG Image"),	"*.jpeg",
     _("TIFF Image"),	"*.tif",
+    _("TIFF Image"),	"*.tiff",
 	NULL
 };
 
@@ -92,8 +100,8 @@ FXDEFMAP(XFileImage) XFileImageMap[]={
                                         FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_OUT,XFileImage::onCmdZoomOut),
                                         FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_100,XFileImage::onCmdZoom100),
                                         FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_WIN,XFileImage::onCmdZoomWin),
-	                                    //FXMAPFUNC(SEL_COMMAND,XFileImage::ID_PRINT,XFileImage::onCmdPrint),
-                                        //FXMAPFUNC(SEL_UPDATE,XFileImage::ID_PRINT,XFileImage::onUpdImage),
+	                                    FXMAPFUNC(SEL_COMMAND,XFileImage::ID_PRINT,XFileImage::onCmdPrint),
+                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_PRINT,XFileImage::onUpdImage),
                                         FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROTATE_90,XFileImage::onUpdImage),
                                         FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROTATE_270,XFileImage::onUpdImage),
                                         FXMAPFUNC(SEL_UPDATE,XFileImage::ID_MIRROR_HOR,XFileImage::onUpdImage),
@@ -118,10 +126,9 @@ FXIMPLEMENT(XFileImage,FXMainWindow,XFileImageMap,ARRAYNUMBER(XFileImageMap))
 
 
 // Make some windows
-XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,600,500,0,0)
+XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,800,600,0,0)
 {
-    FXIcon *bigp=new FXPNGIcon(getApp(),xfi);
-    setIcon(bigp);
+    setIcon(xfiicon);
 
     FXHotKey hotkey;
     FXButton *btn = NULL;
@@ -129,27 +136,6 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,6
     setTarget(this);
     setSelector(ID_TITLE);
 
-    // Create icons
-    uplevelicon=new FXPNGIcon(getApp(),minifolderup);
-	FXPNGIcon *fileopenicon=new FXPNGIcon(getApp(),fileopen);
-	FXPNGIcon *quiticon=new FXPNGIcon(getApp(),quit);
-    FXPNGIcon *rotatelefticon=new FXPNGIcon(getApp(),rotateleft);
-    FXPNGIcon *rotaterighticon=new FXPNGIcon(getApp(),rotateright);
-    FXPNGIcon *zoominicon=new FXPNGIcon(getApp(),zoomin);
-    FXPNGIcon *zoomouticon=new FXPNGIcon(getApp(),zoomout);
-   	FXPNGIcon *zoom100icon=new FXPNGIcon(getApp(),zoom100);
-    FXPNGIcon *zoomwinicon=new FXPNGIcon(getApp(),zoomwin);
-   	FXPNGIcon *mirrorhoricon=new FXPNGIcon(getApp(),fliplr);
-    FXPNGIcon *mirrorvericon=new FXPNGIcon(getApp(),flipud);
-	//FXPNGIcon *printicon=new FXPNGIcon(getApp(),print);	
-	FXPNGIcon *showhiddenicon=new FXPNGIcon(getApp(),showhidden);
-	FXPNGIcon *hidehiddenicon=new FXPNGIcon(getApp(),hidehidden);
-	FXPNGIcon *showthumbicon=new FXPNGIcon(getApp(),showthumb);
-	FXPNGIcon *hidethumbicon=new FXPNGIcon(getApp(),hidethumb);
-	FXPNGIcon *largeicon=new FXPNGIcon(getApp(),bigicons);
-	FXPNGIcon *smallicon=new FXPNGIcon(getApp(),smallicons);
-	FXPNGIcon *detailicon=new FXPNGIcon(getApp(),details);
-
 	// Site where to dock
 	FXDockSite *docksite=new FXDockSite(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
 
@@ -212,13 +198,14 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,6
     new FXToggleButton(statusbar,_("\tShow thumbnails (Ctrl-F7)"),_("\tHide thumbnails (Ctrl-F7)"),showthumbicon,hidethumbicon,this->filelist,
 	                   FileList::ID_TOGGLE_THUMBNAILS,BUTTON_TOOLBAR|LAYOUT_LEFT|ICON_BEFORE_TEXT);
 	new FXStatusBar(statusbar,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
+	new FXDragCorner(statusbar);
 
 
     // Toolbar button: Open file
     new FXButton(toolbar,_("\tOpen Image (Ctrl-O)\tOpen image file. (Ctrl-O)"),fileopenicon,this,ID_OPEN,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
 
     // Toolbar button: Print
-	//new FXButton(toolbar,_("\tPrint image (Ctrl-P)\tPrint image file. (Ctrl-P)"),printicon,this,ID_PRINT,BUTTON_TOOLBAR|FRAME_RAISED);
+	new FXButton(toolbar,_("\tPrint image (Ctrl-P)\tPrint image file. (Ctrl-P)"),printicon,this,ID_PRINT,BUTTON_TOOLBAR|FRAME_RAISED);
 
     // Toolbar button: Quit
     new FXButton(toolbar,_("\tQuit Xfi (Ctrl-Q)\tQuit Xfi. (Ctrl-Q)"),quiticon,this,ID_QUIT,BUTTON_TOOLBAR|FRAME_RAISED);
@@ -252,35 +239,30 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,6
     new FXButton(toolbar,_("\tRotate right (Ctrl-R)\tRotate right image. (Ctrl-R)"),rotaterighticon,this,ID_ROTATE_270,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
 
     // Toolbar button: mirror horizontally
-    new FXButton(toolbar,_("\tMirror horizontally (Ctrl-H)\tMirror image horizontally. (Ctrl-H)"),mirrorhoricon,this,ID_MIRROR_HOR,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
+    new FXButton(toolbar,_("\tMirror horizontally (Ctrl-H)\tMirror image horizontally. (Ctrl-H)"),fliplricon,this,ID_MIRROR_HOR,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
 
     // Toolbar button: mirror vertically
-    new FXButton(toolbar,_("\tMirror vertically (Ctrl-V)\tMirror image vertically. (Ctrl-V)"),mirrorvericon,this,ID_MIRROR_VER,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
+    new FXButton(toolbar,_("\tMirror vertically (Ctrl-V)\tMirror image vertically. (Ctrl-V)"),flipudicon,this,ID_MIRROR_VER,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
 
     // Switch display modes
 	toolbarSeparator(toolbar);
-    new FXButton(toolbar,_("\tBig icons (F10)\tDisplay directory with big icons. (F10)"),largeicon,this,ID_SHOW_BIG,BUTTON_TOOLBAR|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
-    new FXButton(toolbar,_("\tSmall icons (F11)\tDisplay directory with small icons. (F11)"),smallicon,this,ID_SHOW_MINI,BUTTON_TOOLBAR|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
-    new FXButton(toolbar,_("\tFull file list (F12)\tDisplay detailed directory listing. (F12)"),detailicon,this,ID_SHOW_DETAILS,BUTTON_TOOLBAR|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
+    new FXButton(toolbar,_("\tBig icons (F10)\tDisplay directory with big icons. (F10)"),bigiconsicon,this,ID_SHOW_BIG,BUTTON_TOOLBAR|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
+    new FXButton(toolbar,_("\tSmall icons (F11)\tDisplay directory with small icons. (F11)"),smalliconsicon,this,ID_SHOW_MINI,BUTTON_TOOLBAR|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
+    new FXButton(toolbar,_("\tFull file list (F12)\tDisplay detailed directory listing. (F12)"),detailsicon,this,ID_SHOW_DETAILS,BUTTON_TOOLBAR|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
 
     // File Menu entries
     new FXMenuCommand(filemenu,_("&Open...\tCtrl-O\tOpen image file. (Ctrl-O)"),fileopenicon,this,ID_OPEN);
-    //new FXMenuCommand(filemenu,_("&Print image...\tCtrl-P\tPrint image file. (Ctrl-P)"),printicon,this,ID_PRINT);
+    new FXMenuCommand(filemenu,_("&Print image...\tCtrl-P\tPrint image file. (Ctrl-P)"),printicon,this,ID_PRINT);
 
     // Recent file menu; this automatically hides if there are no files
     FXMenuSeparator* sep1=new FXMenuSeparator(filemenu);
     sep1->setTarget(&mrufiles);
     sep1->setSelector(FXRecentFiles::ID_ANYFILES);
-    new FXMenuCommand(filemenu,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_1);
-    new FXMenuCommand(filemenu,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_2);
-    new FXMenuCommand(filemenu,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_3);
-    new FXMenuCommand(filemenu,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_4);
-    new FXMenuCommand(filemenu,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_5);
-    new FXMenuCommand(filemenu,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_6);
-    new FXMenuCommand(filemenu,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_7);
-    new FXMenuCommand(filemenu,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_8);
-    new FXMenuCommand(filemenu,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_9);
-    new FXMenuCommand(filemenu,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_10);
+    new FXMenuCommand(filemenu,FXString::null,NULL,&mrufiles,FXRecentFiles::ID_FILE_1);
+    new FXMenuCommand(filemenu,FXString::null,NULL,&mrufiles,FXRecentFiles::ID_FILE_2);
+    new FXMenuCommand(filemenu,FXString::null,NULL,&mrufiles,FXRecentFiles::ID_FILE_3);
+    new FXMenuCommand(filemenu,FXString::null,NULL,&mrufiles,FXRecentFiles::ID_FILE_4);
+    new FXMenuCommand(filemenu,FXString::null,NULL,&mrufiles,FXRecentFiles::ID_FILE_5);
     new FXMenuCommand(filemenu,_("&Clear recent files\t\tClear recent files."),NULL,&mrufiles,FXRecentFiles::ID_CLEAR);
     FXMenuSeparator* sep2=new FXMenuSeparator(filemenu);
     sep2->setTarget(&mrufiles);
@@ -294,8 +276,8 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,6
     new FXMenuCommand(imagemenu,_("Zoom to fit &window\tCtrl-W\tZoomto fit window. (Ctrl-W)"),zoomwinicon,this,ID_ZOOM_WIN);
     new FXMenuCommand(imagemenu,_("Rotate &right\tCtrl-R\tRotate right. (Ctrl-R)"),rotaterighticon,this,ID_ROTATE_270);
     new FXMenuCommand(imagemenu,_("Rotate &left\tCtrl-L\tRotate left. (Ctrl-L)"),rotatelefticon,this,ID_ROTATE_90);
-    new FXMenuCommand(imagemenu,_("Mirror &horizontally\tCtrl-H\tMirror horizontally. (Ctrl-H)"),mirrorhoricon,this,ID_MIRROR_HOR);
-    new FXMenuCommand(imagemenu,_("Mirror &vertically\tCtrl-V\tMirror vertically. (Ctrl-V)"),mirrorvericon,this,ID_MIRROR_VER);
+    new FXMenuCommand(imagemenu,_("Mirror &horizontally\tCtrl-H\tMirror horizontally. (Ctrl-H)"),fliplricon,this,ID_MIRROR_HOR);
+    new FXMenuCommand(imagemenu,_("Mirror &vertically\tCtrl-V\tMirror vertically. (Ctrl-V)"),flipudicon,this,ID_MIRROR_VER);
 
     // Preferences menu
     new FXMenuCheck(prefsmenu,_("&Toolbar\t\tDisplay toolbar."),toolbar,FXWindow::ID_TOGGLESHOWN);
@@ -340,23 +322,32 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,6
 // Clean up
 XFileImage::~XFileImage()
 {
-    delete filemenu;
+    delete toolbar;
+	delete menubar;
+	delete statusbar;
+	delete filemenu;
     delete imagemenu;
     delete helpmenu;
     delete prefsmenu;
     delete viewmenu;
     delete dragshell1;
     delete dragshell2;
-    delete uplevelicon;
+	delete label;
+	delete filelist;
+	delete img;
+	delete tmpimg;
+	
 }
 
 
 // About box
 long XFileImage::onCmdAbout(FXObject*,FXSelector,void*)
 {
-    FXPNGIcon icon(getApp(),xfi);
-    MessageBox about(this,_("About X File Image"),_("X File Image is a simple image viewer.\n\nCopyright (C) 2002-2006 Roland Baudin (roland65@free.fr)"),&icon,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
-    about.execute();
+    FXString msg=_("X File Image Version ");
+	msg = msg + VERSION + _(" is a simple image viewer.\n\nCopyright (C) 2002-2007 Roland Baudin (roland65@free.fr)");
+    MessageBox about(this,_("About X File Image"),msg.text(),xfiicon,BOX_OK|DECOR_TITLE|DECOR_BORDER);
+    about.execute(PLACEMENT_OWNER);
+
     return 1;
 }
 
@@ -367,11 +358,11 @@ FXbool XFileImage::loadimage(const FXString& file)
     struct stat info;
     FILE *fp;
 
-    FXString ext=FXFile::extension(file);
+    FXString ext=FXPath::extension(file);
 
     if(stat(file.text(),&info)!=0)
     {
-        MessageBox::error(this,MBOX_OK,_("Error Loading File"),_("Non-existing file: %s"),file.text());
+        MessageBox::error(this,BOX_OK,_("Error Loading File"),_("Non-existing file: %s"),file.text());
         return FALSE;
     }
     else
@@ -379,7 +370,7 @@ FXbool XFileImage::loadimage(const FXString& file)
 		fp=fopen(file.text(),"r");
     	if(!fp)
     	{
-        	MessageBox::error(this,MBOX_OK,_("Error Loading File"),_("Unable to open file: %s"),file.text());
+        	MessageBox::error(this,BOX_OK,_("Error Loading File"),_("Unable to open file: %s"),file.text());
         	return FALSE;
     	}
 		else
@@ -400,7 +391,7 @@ FXbool XFileImage::loadimage(const FXString& file)
     {
         img=new FXXPMImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
         tmpimg=new FXXPMImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
-   }
+	}
     else if(comparecase(ext,"pcx")==0)
     {
         img=new FXPCXImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
@@ -435,7 +426,7 @@ FXbool XFileImage::loadimage(const FXString& file)
         img=new FXPNGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
         tmpimg=new FXPNGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
-    else if(comparecase(ext,"jpg")==0)
+    else if(comparecase(ext,"jpg")==0 || comparecase(ext,"jpeg")==0)
     {
         img=new FXJPGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
         tmpimg=new FXJPGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
@@ -445,11 +436,16 @@ FXbool XFileImage::loadimage(const FXString& file)
         img=new FXTIFImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
         tmpimg=new FXTIFImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
+	else
+	{
+		img=NULL;
+		tmpimg=NULL;
+	}
 
     // Perhaps failed
     if(img==NULL || tmpimg==NULL)
     {
-        FXMessageBox::error(this,MBOX_OK,_("Error Loading Image"),_("Unsupported type: %s"),ext.text());
+        MessageBox::error(this,BOX_OK,_("Error Loading Image"),_("Unsupported type: %s"),ext.text());
         return FALSE;
     }
 
@@ -475,7 +471,7 @@ FXbool XFileImage::loadimage(const FXString& file)
 		zoomval=zoomtab[indZoom];
     	getApp()->endWaitCursor();
     }
-    filelist->setDirectory(FXFile::directory(file));
+    filelist->setDirectory(FXPath::directory(file));
     return TRUE;
 }
 
@@ -484,7 +480,7 @@ FXbool XFileImage::loadimage(const FXString& file)
 // Open
 long XFileImage::onCmdOpen(FXObject*,FXSelector,void*)
 {
-    FileDialog open(this,_("Open Image"));
+    FileDialog open(this,_("Open Image"),0,0,0,600,400);
 	open.setSelectMode(SELECTFILE_EXISTING);
     open.setPatternList(patterns);
   	open.setDirectory(filelist->getDirectory());
@@ -499,17 +495,37 @@ long XFileImage::onCmdOpen(FXObject*,FXSelector,void*)
 }
 
 
-/*
-// Print the image
+// Print the text
 long XFileImage::onCmdPrint(FXObject*,FXSelector,void*)
 {
-	FXPrintDialog dlg(this,_("Print Image"));
-	FXPrinter printer;
-	if(dlg.execute())
-    	dlg.getPrinter(printer);
-  	return 1;
+    // Read the current print command from the registry
+    FXString printcommand, command;	
+	printcommand=getApp()->reg().readStringEntry("SETTINGS","print_command","lpr -P printer");
+	
+	// Open print dialog filled with the current print command
+	int rc=1;
+	InputDialog* dialog;
+	dialog=new InputDialog(this,printcommand,_("Enter print command: \n(ex: lpr -P <printer>)"),_("Print"),"",printbigicon);    
+	dialog->setText(printcommand);
+	dialog->CursorEnd();
+    rc=dialog->execute(PLACEMENT_CURSOR);
+	printcommand=dialog->getText();
+	delete dialog;
+	
+	// If cancel was pressed, exit
+	if (!rc)
+		return 0;
+	
+	// Write the new print command to the registry
+	getApp()->reg().writeStringEntry("SETTINGS","print_command",printcommand.text());
+	
+	// Perform the print command
+	command =  "cat " + filename + " |" + printcommand + " &";
+	system(command.text());
+	
+    return 1;
 }
-*/
+
 
 // Handle toggle hidden command
 long XFileImage::onCmdToggleHidden(FXObject* sender,FXSelector sel,void* ptr)
@@ -969,7 +985,7 @@ void XFileImage::create()
     FXuint fh=getApp()->reg().readIntEntry("SETTINGS","fileheight",100);
     FXuint fs=getApp()->reg().readIntEntry("SETTINGS","filesshown",TRUE);
 
-    filelist->setDirectory(FXFile::getCurrentDirectory());
+    filelist->setDirectory(FXSystem::getCurrentDirectory());
 
     filebox->setHeight(fh);
 
@@ -1045,7 +1061,7 @@ void XFileImage::saveConfig()
 
 // Usage message
 #define USAGE_MSG	_("\
-Usage: xfi [options] [image] \n\
+\nUsage: xfi [options] [image] \n\
 \n\
     [options] can be any of the following:\n\
 \n\
@@ -1063,9 +1079,10 @@ int main(int argc,char *argv[])
 {
 	int i;
 	FXString startimage="";
-	char *appname = "Xfi";
-	char *xfename = "Xfe";
-	char *vdrname = "XFileExplorer";
+	char *appname = "xfirc";
+	char *xfename = CONFIGNAME;
+	char *vdrname = "";
+	FXbool loadicons;
 
 #ifdef HAVE_SETLOCALE
   // Set locale via LC_ALL.
@@ -1073,9 +1090,10 @@ int main(int argc,char *argv[])
 #endif
 
 #if ENABLE_NLS
-  // Set the text message domain.
-  bindtextdomain (PACKAGE, LOCALEDIR);
-  textdomain (PACKAGE);
+	// Set the text message domain.
+	bindtextdomain (PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset(PACKAGE,"utf-8");
+	textdomain (PACKAGE);
 #endif
 
 	// Parse basic arguments
@@ -1106,6 +1124,9 @@ int main(int argc,char *argv[])
     // Open display
     application->init(argc,argv);
 
+	// Load all application icons
+	loadicons=loadAppIcons(application);
+	
     // Read the Xfe registry
 	FXRegistry* reg=new FXRegistry(xfename,vdrname);
 	reg->read();
@@ -1129,6 +1150,8 @@ int main(int argc,char *argv[])
     bordercolor=reg->readColorEntry("SETTINGS","bordercolor",FXRGB(0,0,0));
 	listbackcolor=reg->readColorEntry("SETTINGS","listbackcolor",FXRGB(255,255,255));
 	listforecolor=reg->readColorEntry("SETTINGS","listforecolor",FXRGB(0,0,0));
+	listforecolor=reg->readColorEntry("SETTINGS","listforecolor",FXRGB(0,0,0));
+	highlightcolor=reg->readColorEntry("SETTINGS","highlightcolor",FXRGB(238,238,238));
 	application->setBaseColor(basecolor);
 	application->setForeColor(forecolor);
 	application->setBackColor(backcolor);
@@ -1148,6 +1171,8 @@ int main(int argc,char *argv[])
  
     // Create it
     application->create();
+	if (!loadicons)
+		 MessageBox::error(application,BOX_OK,_("Error loading icons"),_("Unable to load some icons. Please check your icons path!"));
 
     // Start
     window->start(startimage);
