@@ -27,19 +27,18 @@ protected:
     FXMenuPane        *imagemenu;             // Image menu
     FXMenuPane        *prefsmenu;             // Preferences menu
     FXTextField       *filter;                // Filter for tree list
-    FXIcon            *uplevelicon;           // Icon for up level directory
 	FXImage			  *img;					  // Image loaded
-	FXImage			  *tmpimg;					// Temporary image
-    FXColor 		  *tmpdata;					// Temporary image data
-	FXint			  indZoom;					// Zoom index
-	FXdouble		  zoomval;					// Actual zoom factor					
+	FXImage			  *tmpimg;				  // Temporary image
+    FXColor 		  *tmpdata;				  // Temporary image data
+	FXint			  indZoom;				  // Zoom index
+	FXdouble		  zoomval;				  // Actual zoom factor					
 protected:
     XFileImage()
     {}
 public:
     long onCmdAbout(FXObject*,FXSelector,void*);
     long onCmdOpen(FXObject*,FXSelector,void*);
-	//long onCmdPrint(FXObject*,FXSelector,void*);
+	long onCmdPrint(FXObject*,FXSelector,void*);
 	long onCmdShowMini(FXObject*,FXSelector,void*);
  	long onCmdShowBig(FXObject*,FXSelector,void*);
  	long onCmdShowDetails(FXObject*,FXSelector,void*);
@@ -77,7 +76,7 @@ public:
 		ID_COLS,
 		ID_ROWS,
         ID_TITLE,
-		//ID_PRINT,
+		ID_PRINT,
         ID_QUIT,
         ID_FILELIST,
         ID_RECENTFILE,
