@@ -3,9 +3,9 @@
 #include "config.h"
 #include "i18n.h"
 
-#include <fox-1.4/fx.h>
-#include <fox-1.4/fxkeys.h>
-#include <fox-1.4/FXPNGIcon.h>
+#include <fox-1.6/fx.h>
+#include <fox-1.6/fxkeys.h>
+#include <fox-1.6/FXPNGIcon.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -13,6 +13,7 @@
 #include <unistd.h>
 #include <sys/stat.h>
 
+#include "xfedefs.h"
 #include "icons.h"
 #include "File.h"
 #include "FileDialog.h"
@@ -20,6 +21,10 @@
 #include "XFileQuery.h"
 #include "CommandWindow.h"
 
+
+// Add FOX hacks
+#include "foxhacks.cc"
+
 // Maximum length of a file name
 #ifndef MAXPATHLEN
 #define MAXPATHLEN 1024
@@ -27,6 +32,10 @@
 
 FXMainWindow *mainWindow;
 char **args;
+FXbool dpkg=FALSE;
+FXbool rpm=FALSE;
+FXColor highlightcolor;
+FXbool allowPopupScroll=FALSE;
 
 // Map
 FXDEFMAP(XFileQuery) XFileQueryMap[]={
@@ -34,7 +43,7 @@ FXDEFMAP(XFileQuery) XFileQueryMap[]={
                                          FXMAPFUNC(SEL_COMMAND,XFileQuery::ID_UNINSTALL,XFileQuery::onCmdUninstall),
                                        	 FXMAPFUNC(SEL_COMMAND,XFileQuery::ID_ABOUT,XFileQuery::onCmdAbout),
                                        	 FXMAPFUNC(SEL_COMMAND,XFileQuery::ID_OPEN,XFileQuery::onCmdOpen),
-                                         FXMAPFUNC(SEL_COMMAND,XFileQuery::ID_UPGRADE,XFileQuery::onCmdUpgrade),
+                                         FXMAPFUNC(SEL_COMMAND,XFileQuery::ID_INSTALL,XFileQuery::onCmdInstall),
                                          FXMAPFUNC(SEL_UPDATE,XFileQuery::ID_DESCRIPTION,XFileQuery::onUpdDescription),
                                          FXMAPFUNC(SEL_UPDATE,XFileQuery::ID_FILELIST,XFileQuery::onUpdFileList),
                                      };
@@ -44,15 +53,10 @@ FXDEFMAP(XFileQuery) XFileQueryMap[]={
 FXIMPLEMENT(XFileQuery,FXMainWindow,XFileQueryMap,ARRAYNUMBER(XFileQueryMap))
 
 // Constructor
-XFileQuery::XFileQuery(FXApp *a):FXMainWindow(a,"Xfq",NULL,NULL,DECOR_ALL,0,0,600,500,0,0)
+XFileQuery::XFileQuery(FXApp *a):FXMainWindow(a,"Xfq",NULL,NULL,DECOR_ALL,0,0,800,600,0,0)
 {
-    FXIcon *bigicon=new FXPNGIcon(getApp(),xfq);
-    setIcon(bigicon);
-
-    // Create icons
-	FXPNGIcon *fileopenicon=new FXPNGIcon(getApp(),fileopen);
-	FXPNGIcon *quiticon=new FXPNGIcon(getApp(),quit);
-
+    setIcon(xfqicon);
+		
 	// Site where to dock
 	FXDockSite *docksite=new FXDockSite(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
 
@@ -72,7 +76,7 @@ XFileQuery::XFileQuery(FXApp *a):FXMainWindow(a,"Xfq",NULL,NULL,DECOR_ALL,0,0,60
     new FXMenuTitle(menubar,_("&File"),NULL,filemenu);
 
     // Preferences Menu
-    FXMenuPane *prefsmenu=new FXMenuPane(this);
+    prefsmenu=new FXMenuPane(this);
     new FXMenuTitle(menubar,_("&Preferences"),NULL,prefsmenu);
 
     // Help menu
@@ -100,10 +104,8 @@ XFileQuery::XFileQuery(FXApp *a):FXMainWindow(a,"Xfq",NULL,NULL,DECOR_ALL,0,0,60
     new FXToolTip(getApp(),0);
 
     // Buttons
-    FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
-
-    // Make contents
-    contents=new FXHorizontalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
+    FXHorizontalFrame* buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
+	new FXDragCorner(buttons);
 
     // Close
     new FXButton(buttons,_("&Close"),NULL,this,XFileQuery::ID_QUIT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
@@ -112,41 +114,46 @@ XFileQuery::XFileQuery(FXApp *a):FXMainWindow(a,"Xfq",NULL,NULL,DECOR_ALL,0,0,60
     new FXButton(buttons,_("&Uninstall"),NULL,this,XFileQuery::ID_UNINSTALL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
 
     // Install/Upgrade
-    new FXButton(buttons,_("&Install/Upgrade"),NULL,this,XFileQuery::ID_UPGRADE,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+    new FXButton(buttons,_("&Install/Upgrade"),NULL,this,XFileQuery::ID_INSTALL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
 
     // Switcher
-    FXTabBook *tabbook = new FXTabBook(contents,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_RIGHT);
+    FXTabBook* tabbook = new FXTabBook(this,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_RIGHT);
 
     // First item is Description
     new FXTabItem(tabbook,_("&Description"),NULL);
-    FXVerticalFrame *descr=new FXVerticalFrame(tabbook,FRAME_RAISED);
-    FXPacker *p=new FXPacker(descr,FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    description=new FXText(p,this,XFileQuery::ID_DESCRIPTION,FRAME_SUNKEN|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXVerticalFrame *descr=new FXVerticalFrame(tabbook);
+	FXPacker *p=new FXPacker(descr,FRAME_SUNKEN|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    description=new FXText(p,this,XFileQuery::ID_DESCRIPTION,LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     // Second item is File List
-    new FXTabItem(tabbook,_("&File List"),NULL);
-    FXVerticalFrame *flistfr=new FXVerticalFrame(tabbook,FRAME_RAISED);
-    p=new FXPacker(flistfr,FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    new FXTabItem(tabbook,_("File &List"),NULL);
+    FXVerticalFrame *flistfr=new FXVerticalFrame(tabbook);
+    p=new FXPacker(flistfr,FRAME_SUNKEN|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 	list=new FXTreeList(p,this,XFileQuery::ID_FILELIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|TREELIST_SHOWS_LINES);
 
-	// Folder icons for file list
-    folder_open=new FXPNGIcon(getApp(),package);
-    folder_closed=new FXPNGIcon(getApp(),package);
-
-    // Document icon for file list
-    doc=new FXPNGIcon(getApp(),minidoc);
-
 	// Initialize file name
 	filename="";
 }
 
+// Destructor
+XFileQuery::~XFileQuery()
+{
+    delete menubar;
+    delete toolbar;
+	delete filemenu;
+	delete prefsmenu;
+	delete helpmenu;
+    delete list;
+	delete description;
+}
 
 // About box
 long XFileQuery::onCmdAbout(FXObject*,FXSelector,void*)
 {
-    FXPNGIcon icon(getApp(),xfq);
-    MessageBox about(this,_("About X File Query"),_("X File Query is a simple RPM manager.\n\nCopyright (C) 2002-2006 Roland Baudin (roland65@free.fr)"),&icon,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
-    about.execute();
+    FXString msg=_("X File Query Version ");
+	msg = msg + VERSION + _(" is a simple rpm or deb package manager.\n\nCopyright (C) 2002-2007 Roland Baudin (roland65@free.fr)");
+	MessageBox about(this,_("About X File Query"),msg.text(),xfqicon,BOX_OK|DECOR_TITLE|DECOR_BORDER);
+    about.execute(PLACEMENT_OWNER);
     return 1;
 }
 
@@ -158,12 +165,13 @@ long XFileQuery::onCmdOpen(FXObject*,FXSelector,void*)
             _("All Files"),			"*",
             _("RPM source packages"),	"*.src.rpm",
             _("RPM packages"),			"*.rpm",
+            _("DEB packages"),			"*.deb",
 			NULL
         };
     FileDialog open(this,_("Open Document"));
 	open.setSelectMode(SELECTFILE_EXISTING);
     open.setPatternList(patterns);
-  	open.setDirectory(FXFile::directory(filename));
+  	open.setDirectory(FXPath::directory(filename));
     if(open.execute())
     {
         filename=open.getFilename();
@@ -173,57 +181,90 @@ long XFileQuery::onCmdOpen(FXObject*,FXSelector,void*)
     return 1;
 }
 
-// Install/upgrade RPM package
-long XFileQuery::onCmdUpgrade(FXObject*,FXSelector,void*)
+// Install/upgrade package
+long XFileQuery::onCmdInstall(FXObject*,FXSelector,void*)
 {
+	FXString cmd;
+	
 	getApp()->flush();
 
 	if (strlen(filename.text())==0)
 	{
-        MessageBox::error(this,MBOX_OK,_("Error"),_("No RPM package loaded"));
+        MessageBox::error(this,BOX_OK,_("Error"),_("No package loaded"));
 		return 0;
 	}
 		
 	// Package name
-    FXString package;
-	package=FXFile::name(filename);
+    FXString package=FXPath::name(filename);
 
     // Command to perform
-	FXString cmd="rpm -Uvh " +filename;
+	FXString ext=FXPath::extension(filename);
+    if(comparecase(ext,"rpm")==0)
+		cmd="rpm -Uvh "+filename;
+	else if(comparecase(ext,"deb")==0)
+		cmd="dpkg -i "+filename;
+	else
+	{
+		MessageBox::error(this,BOX_OK,_("Error"),_("Unknown package format"));
+		return 0;
+	}
 
     // Make and show command window
-	CommandWindow *cmdwin=new CommandWindow(mainWindow,_("Install/Upgrade RPM"),cmd,10,80);			
+	CommandWindow *cmdwin=new CommandWindow(mainWindow,_("Install/Upgrade Package"),cmd,10,80);			
 	cmdwin->create();
 
+	FXString msg=_("Installing package : ") + package + "\n"; 
+	cmdwin->appendText(msg.text());
+
 	// The CommandWindow object will delete itself when closed!
 
     return 1;
 }
 
 
-// Uninstall RPM package based on the package name (version is ignored)
+// Uninstall package based on the package name (version is ignored)
 long XFileQuery::onCmdUninstall(FXObject*,FXSelector,void*)
 {
+	FXString cmd;
+
 	getApp()->flush();
 	
 	if (strlen(filename.text())==0)
 	{
-        MessageBox::error(this,MBOX_OK,_("Error"),_("No RPM package loaded"));
+        MessageBox::error(this,BOX_OK,_("Error"),_("No package loaded"));
 		return 0;
 	}
 
-	// Get package name
-    FXString package;
-	package=FXFile::name(filename);
-	package=package.section('-',0);
-    
-	// Uninstall command
-	FXString cmd="rpm -e " + package;
+    // Command to perform
+	FXString package;
+	FXString ext=FXPath::extension(filename);
+    if(comparecase(ext,"rpm")==0)
+	{
+		// Get package name
+		package=FXPath::name(filename);
+		package=package.section('-',0);
+		cmd="rpm -e "+ package;
+	}
+	else if(comparecase(ext,"deb")==0)
+	{
+		// Get package name
+		package=FXPath::name(filename);
+		package=package.section('_',0);
+		cmd="dpkg -r "+ package;
+	}
+	else
+	{
+		MessageBox::error(this,BOX_OK,_("Error"),_("Unknown package format"));
+		return 0;
+	}
 
     // Make and show command window
-	CommandWindow *cmdwin=new CommandWindow(mainWindow,_("Uninstall RPM"),cmd,10,80);			
+	CommandWindow *cmdwin=new CommandWindow(mainWindow,_("Uninstall Package"),cmd,10,80);			
 	cmdwin->create();
 
+	FXString msg=_("Uninstalling package : ") + package + "\n"; 
+	cmdwin->appendText(msg.text());
+
 	// The CommandWindow object will delete itself when closed!
 
     return 1;
@@ -268,11 +309,24 @@ long XFileQuery::onCmdQuit(FXObject*,FXSelector,void*)
 // Update file list
 long XFileQuery::onUpdFileList(FXObject*,FXSelector,void*)
 {
+	FXString cmd;
+
 	if(!list_clean)
         return 0;
 	
     list_clean=FALSE;
-    FXString cmd="rpm -qlp '"+filename+"'";
+ 
+	FXString ext=FXPath::extension(filename);
+    if(comparecase(ext,"rpm")==0)
+		cmd="rpm -qlp '"+filename+"'";
+	else if(comparecase(ext,"deb")==0)
+		cmd="dpkg -c '"+filename+"'";
+	else
+	{
+		MessageBox::error(this,BOX_OK,_("Error"),_("File list : Unknown package format"));
+		return 0;
+	}
+
     FILE *rpmcmd=popen(cmd.text(),"r");
     if(!rpmcmd)
     {
@@ -281,7 +335,7 @@ long XFileQuery::onUpdFileList(FXObject*,FXSelector,void*)
     }
     char text[10000]={0};
     FXString str;
-    str=FXFile::name(filename);
+    str=FXPath::name(filename);
     strlcpy(text,str.text(),str.length()+1);
 
 	// Clear list
@@ -289,14 +343,14 @@ long XFileQuery::onUpdFileList(FXObject*,FXSelector,void*)
 
     // First item
 	FXTreeItem *topmost;
-	topmost=list->prependItem(NULL,text,folder_open,folder_closed);
-    
+	topmost=list->prependItem(NULL,text,minifoldericon,minifolderopenicon);
+   
 	// Next items
 	while(fgets(text,sizeof(text),rpmcmd))
     {
         text[strlen(text)-1]='\0';// kill trailing lf
-        list->appendItem(topmost,text,doc,doc);
-    }
+        list->appendItem(topmost,text,minidocicon,minidocicon);
+  }
     list->expandTree(topmost);
     pclose(rpmcmd);
     return 1;
@@ -306,23 +360,53 @@ long XFileQuery::onUpdFileList(FXObject*,FXSelector,void*)
 // Update description
 long XFileQuery::onUpdDescription(FXObject*,FXSelector,void*)
 {
+	FXString cmd;
+
     if(!desc_clean)
         return 0;
     desc_clean=FALSE;
-    FXString cmd="rpm -qip '"+filename+"'";
+
+    FXString buf;
+	FXString ext=FXPath::extension(filename);
+    if(comparecase(ext,"rpm")==0)
+	{
+		cmd="rpm -qip '"+filename+"'";
+		buf += _("[RPM package]\n"); 
+	}
+	else if(comparecase(ext,"deb")==0)
+	{
+		buf += _("[DEB package]\n"); 
+		cmd="dpkg -I '"+filename+"'";
+	}
+	else
+	{
+		MessageBox::error(this,BOX_OK,_("Error"),_("Description : Unknown package format"));
+		return 0;
+	}
+
     FILE *rpmcmd=popen(cmd.text(),"r");
     if(!rpmcmd)
     {
         perror("popen");
         exit(1);
     }
+	
+    // Don't display the header for Debian packages
+	int suppress_header=0;
+	if(comparecase(ext,"deb")==0)
+		suppress_header=1;
+
     char text[10000]={0};
-    FXString buf;
     while(fgets(text,sizeof(text),rpmcmd))
-        buf+=text;
+    {
+		if (suppress_header)
+			suppress_header = (strstr(text,"Package:")==NULL); 
+        if (!suppress_header) 
+			buf+=text;
+    }
     if(pclose(rpmcmd))
     {
-        MessageBox::error(this,MBOX_OK,_("Error"),_("Query of %s failed!"),filename.text());
+        MessageBox::error(this,BOX_OK,_("Error"),_("Query of %s failed!"),filename.text());
 		list->clearItems();
         description->setText("");
 		filename="";
@@ -346,7 +430,7 @@ void XFileQuery::start(FXString startpkg)
     	FILE *fp;
     	if(stat(filename.text(),&info)!=0)
     	{
-        	MessageBox::error(this,MBOX_OK,_("Error Loading File"),_("Non-existing file: %s"),filename.text());
+        	MessageBox::error(this,BOX_OK,_("Error Loading File"),_("Non-existing file: %s"),filename.text());
 			filename="";
 			desc_clean=FALSE;
     		list_clean=FALSE;
@@ -356,7 +440,7 @@ void XFileQuery::start(FXString startpkg)
 			fp=fopen(filename.text(),"r");
     		if(!fp)
     		{
-        		MessageBox::error(this,MBOX_OK,_("Error Loading File"),_("Unable to open file: %s"),filename.text());
+        		MessageBox::error(this,BOX_OK,_("Error Loading File"),_("Unable to open file: %s"),filename.text());
 				filename="";
 				desc_clean=FALSE;
     			list_clean=FALSE;
@@ -380,7 +464,7 @@ void XFileQuery::start(FXString startpkg)
 void XFileQuery::create()
 {
     // Read the Xfe registry
-	FXRegistry* reg_xfe=new FXRegistry("Xfe",NULL);
+	FXRegistry* reg_xfe=new FXRegistry(CONFIGNAME,"");
 	reg_xfe->read();
 	
 	// Set Xfq text font according to the Xfe registry
@@ -394,11 +478,6 @@ void XFileQuery::create()
 	}
 	delete reg_xfe;
 	
-	// Create icons
-	folder_open->create();
-	folder_closed->create();
-	doc->create();
-
 	// Wheel scrolling
     FXint wheellines=getApp()->reg().readUnsignedEntry("SETTINGS","wheellines",5);
 	getApp()->setWheelLines(wheellines);
@@ -424,14 +503,14 @@ void XFileQuery::create()
 
 // Usage message
 #define USAGE_MSG	_("\
-Usage: xfq [options] [package] \n\
+\nUsage: xfq [options] [package] \n\
 \n\
     [options] can be any of the following:\n\
 \n\
         -h, --help         Print (this) help screen and exit.\n\
         -v, --version      Print version information and exit.\n\
 \n\
-    [package] is the path to the rpm package you want to open on start up.\n\
+    [package] is the path to the rpm or deb package you want to open on start up.\n\
 \n")
 
 
@@ -441,9 +520,10 @@ int main(int argc,char* argv[])
 {
 	int i;
 	FXString startpkg="";
-	char *appname = "Xfq";
-	char *xfename = "Xfe";
-	char *vdrname = "XFileExplorer";
+	char *appname = "xfqrc";
+	char *xfename = CONFIGNAME;
+	char *vdrname = "";
+	FXbool loadicons;
 
 #ifdef HAVE_SETLOCALE
   // Set locale via LC_ALL.
@@ -451,9 +531,10 @@ int main(int argc,char* argv[])
 #endif
 
 #if ENABLE_NLS
-  // Set the text message domain.
-  bindtextdomain (PACKAGE, LOCALEDIR);
-  textdomain (PACKAGE);
+	// Set the text message domain.
+	bindtextdomain (PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset(PACKAGE,"utf-8");
+	textdomain (PACKAGE);
 #endif
 
 	XFileQuery *window;
@@ -487,6 +568,9 @@ int main(int argc,char* argv[])
     // Open display
     application->init(argc,argv);
 
+	// Load all application icons
+	loadicons=loadAppIcons(application);
+
     // Read the Xfe registry
 	FXRegistry *reg;
   	reg=new FXRegistry(xfename,vdrname);
@@ -525,25 +609,51 @@ int main(int argc,char* argv[])
 
     // Create it
     application->create();
-
-    // Test the existence of the RedHat package manager (RPM)
+	if (!loadicons)
+		 MessageBox::error(application,BOX_OK,_("Error loading icons"),_("Unable to load some icons. Please check your icons path!"));
+	
+    // Test the existence of the Debian package manager (dpkg)
+	// This is done by checking the existence of the string 'Debian'
+	// in the response to the command 'dpkg' (with --version argument)
+	FXString cmd="dpkg --version 2>&1";
+    FILE *debcmd=popen(cmd.text(),"r");
+    if(!debcmd)
+    {
+        perror("popen");
+        exit(1);
+    }
+    char textdeb[10000]={0};
+    FXString bufdeb;
+    while(fgets(textdeb,sizeof(textdeb),debcmd))
+        bufdeb+=textdeb;
+    snprintf(textdeb,sizeof(textdeb)-1,"%s",bufdeb.text());
+	if (strstr(textdeb,"Debian")!=NULL)
+		dpkg=TRUE;
+	pclose(debcmd);
+	
+    // Test the existence of the RedHat package manager (rpm)
 	// This is done by checking the existence of the string 'RPM'
-	// in the response to the command 'rpm' (with no arguments)
-	FXString cmd="rpm 2>&1";
+	// in the response to the command 'rpm --version'
+	cmd="rpm --version 2>&1";
     FILE *rpmcmd=popen(cmd.text(),"r");
     if(!rpmcmd)
     {
         perror("popen");
         exit(1);
     }
-    char text[10000]={0};
-    FXString buf;
-    while(fgets(text,sizeof(text),rpmcmd))
-        buf+=text;
-    snprintf(text,sizeof(text)-1,"%s",buf.text());
-	if (strstr(text,"RPM")==NULL)
+    char textrpm[10000]={0};
+    FXString bufrpm;
+    while(fgets(textrpm,sizeof(textrpm),rpmcmd))
+        bufrpm+=textrpm;
+    snprintf(textrpm,sizeof(textrpm)-1,"%s",bufrpm.text());
+	if (strstr(textrpm,"RPM")!=NULL)
+		rpm=TRUE;
+	pclose(rpmcmd);
+	
+	// No package manager was found
+	if ((dpkg==FALSE) && (rpm==FALSE))
 	{
-        MessageBox::error(window,MBOX_OK,_("Error"),_("RedHat package manager (RPM) not found!"));
+        MessageBox::error(window,BOX_OK,_("Error"),_("No compatible package manager (rpm or dpkg) found!"));
 		exit(1);
 	}
 
